@@ -17,6 +17,7 @@
 
 package org.apache.hop.core;
 
+import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringEscapeUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.lang.exception.ExceptionUtils;
@@ -283,6 +284,14 @@ public class Const {
   public static final String INTERNAL_VARIABLE_WORKFLOW_NAME =
       INTERNAL_VARIABLE_PREFIX + ".Workflow.Name";
 
+  /** The workflow ID */
+  public static final String INTERNAL_VARIABLE_WORKFLOW_ID =
+          INTERNAL_VARIABLE_PREFIX + ".Workflow.ID";
+
+  /** The workflow parent ID */
+  public static final String INTERNAL_VARIABLE_WORKFLOW_PARENT_ID =
+          INTERNAL_VARIABLE_PREFIX + ".Workflow.ParentID";
+
   /** The current pipeline directory */
   public static final String INTERNAL_VARIABLE_ENTRY_CURRENT_FOLDER =
       INTERNAL_VARIABLE_PREFIX + ".Entry.Current.Folder";
@@ -315,6 +324,14 @@ public class Const {
   public static final String INTERNAL_VARIABLE_PIPELINE_NAME =
       INTERNAL_VARIABLE_PREFIX + ".Pipeline.Name";
 
+  /** The pipeline ID */
+  public static final String INTERNAL_VARIABLE_PIPELINE_ID =
+          INTERNAL_VARIABLE_PREFIX + ".Pipeline.ID";
+
+  /** The pipeline parent ID */
+  public static final String INTERNAL_VARIABLE_PIPELINE_PARENT_ID =
+          INTERNAL_VARIABLE_PREFIX + ".Pipeline.ParentID";
+
   /** The transform partition ID */
   public static final String INTERNAL_VARIABLE_TRANSFORM_PARTITION_ID =
       INTERNAL_VARIABLE_PREFIX + ".Transform.Partition.ID";
@@ -331,6 +348,16 @@ public class Const {
   public static final String INTERNAL_VARIABLE_TRANSFORM_COPYNR =
       INTERNAL_VARIABLE_PREFIX + ".Transform.CopyNr";
 
+  public static final String INTERNAL_VARIABLE_TRANSFORM_ID =
+          INTERNAL_VARIABLE_PREFIX + ".Transform.ID";
+
+  public static final String INTERNAL_VARIABLE_TRANSFORM_BUNDLE_NR =
+          INTERNAL_VARIABLE_PREFIX + ".Transform.BundleNr";
+
+
+  public static final String INTERNAL_VARIABLE_ACTION_ID =
+          INTERNAL_VARIABLE_PREFIX + ".Action.ID";
+
   /** The default maximum for the nr of lines in the GUI logs */
   public static final int MAX_NR_LOG_LINES = 5000;
 
@@ -848,6 +875,17 @@ public class Const {
           "This is the name of the variable which when set should contains the path to a file which will be included in the serialization of pipelines and workflows")
   public static final String HOP_LICENSE_HEADER_FILE = "HOP_LICENSE_HEADER_FILE";
 
+  /**
+   * The variable says Hop to consider nulls when parsing JSON files
+   */
+  @Variable(value = "N",
+      description =
+          "Name of te variable to set so that Nulls are considered while parsing JSON files. If HOP_JSON_INPUT_INCLUDE_NULLS is \"Y\" then nulls will be included otherwise they will not be included (default behavior)")
+  public static final String HOP_JSON_INPUT_INCLUDE_NULLS = "HOP_JSON_INPUT_INCLUDE_NULLS";
+  /** By default, HOP do not consider NULLS while parsing input */
+  public static final String JSON_INPUT_INCLUDE_NULLS = "N";
+
+
   /** The i18n prefix to signal that this is a String in the format: i18n:package:key */
   public static final String I18N_PREFIX = "i18n:";
 
@@ -2335,16 +2373,7 @@ public class Const {
    * @return An array of all default conversion formats, to be used in dialogs etc.
    */
   public static String[] getConversionFormats() {
-    String[] dats = Const.getDateFormats();
-    String[] nums = Const.getNumberFormats();
-    int totsize = dats.length + nums.length;
-    String[] formats = new String[totsize];
-    System.arraycopy(dats, 0, formats, 0, dats.length);
-    for (int x = 0; x < nums.length; x++) {
-      formats[dats.length + x] = nums[x];
-    }
-
-    return formats;
+    return (String[]) ArrayUtils.addAll(Const.getDateFormats(), Const.getNumberFormats());
   }
 
   /**
