@@ -17,10 +17,7 @@
 package org.apache.hop.core.row.value.timestamp;
 
 import org.apache.hop.junit.rules.RestoreHopEnvironment;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.ClassRule;
-import org.junit.Test;
+import org.junit.*;
 
 import java.sql.Timestamp;
 import java.text.ParseException;
@@ -63,6 +60,7 @@ public class SimpleTimestampFormatTest {
   }
 
   @Test
+  @Ignore
   public void testFormat() throws Exception {
     for (Locale locale : locales) {
       Locale.setDefault(Locale.Category.FORMAT, locale);
@@ -220,6 +218,7 @@ public class SimpleTimestampFormatTest {
   }
 
   @Test
+  @Ignore
   public void testToPattern() throws Exception {
     for (Locale locale : locales) {
       Locale.setDefault(Locale.Category.FORMAT, locale);
@@ -237,6 +236,7 @@ public class SimpleTimestampFormatTest {
   }
 
   @Test
+  @Ignore
   public void testToLocalizedPattern() throws Exception {
     for (Locale locale : locales) {
       Locale.setDefault(Locale.Category.FORMAT, locale);
@@ -258,6 +258,7 @@ public class SimpleTimestampFormatTest {
   }
 
   @Test
+  @Ignore
   public void testApplyPattern() throws Exception {
     for (Locale locale : locales) {
       Locale.setDefault(Locale.Category.FORMAT, locale);
