@@ -20,6 +20,7 @@ package org.apache.hop.pipeline.config;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hop.core.variables.DescribedVariable;
 import org.apache.hop.core.variables.IVariables;
+import org.apache.hop.execution.profiling.ExecutionDataProfile;
 import org.apache.hop.metadata.api.HopMetadata;
 import org.apache.hop.metadata.api.HopMetadataBase;
 import org.apache.hop.metadata.api.HopMetadataProperty;
@@ -41,10 +42,19 @@ public class PipelineRunConfiguration extends HopMetadataBase implements Cloneab
 
   @HopMetadataProperty private String description;
 
+  /**
+   * The name of the location to send execution information to
+   */
+  @HopMetadataProperty private String executionInfoLocationName;
+
   @HopMetadataProperty private List<DescribedVariable> configurationVariables;
 
   @HopMetadataProperty private IPipelineEngineRunConfiguration engineRunConfiguration;
 
+  /** The name of an {@link ExecutionDataProfile} */
+  @HopMetadataProperty(key="dataProfile")
+  protected String executionDataProfileName;
+
   public PipelineRunConfiguration() {
     configurationVariables = new ArrayList<>();
   }
@@ -52,22 +62,28 @@ public class PipelineRunConfiguration extends HopMetadataBase implements Cloneab
   public PipelineRunConfiguration(
       String name,
       String description,
+      String executionInfoLocationName,
       List<DescribedVariable> configurationVariables,
-      IPipelineEngineRunConfiguration engineRunConfiguration) {
+      IPipelineEngineRunConfiguration engineRunConfiguration,
+      String executionDataProfileName) {
     this.name = name;
     this.description = description;
+    this.executionInfoLocationName = executionInfoLocationName;
     this.configurationVariables = configurationVariables;
     this.engineRunConfiguration = engineRunConfiguration;
+    this.executionDataProfileName = executionDataProfileName;
   }
 
   public PipelineRunConfiguration(PipelineRunConfiguration runConfiguration) {
     this();
     this.name = runConfiguration.name;
     this.description = runConfiguration.description;
+    this.executionInfoLocationName = runConfiguration.executionInfoLocationName;
     this.configurationVariables.addAll(runConfiguration.getConfigurationVariables());
     if (runConfiguration.getEngineRunConfiguration() != null) {
       this.engineRunConfiguration = runConfiguration.engineRunConfiguration.clone();
     }
+    this.executionDataProfileName = runConfiguration.executionDataProfileName;
   }
 
   /**
@@ -84,6 +100,24 @@ public class PipelineRunConfiguration extends HopMetadataBase implements Cloneab
     this.description = description;
   }
 
+  /**
+   * Gets executionInfoLocationName
+   *
+   * @return value of executionInfoLocationName
+   */
+  public String getExecutionInfoLocationName() {
+    return executionInfoLocationName;
+  }
+
+  /**
+   * Sets executionInfoLocationName
+   *
+   * @param executionInfoLocationName value of executionInfoLocationName
+   */
+  public void setExecutionInfoLocationName(String executionInfoLocationName) {
+    this.executionInfoLocationName = executionInfoLocationName;
+  }
+
   /**
    * Gets configurationVariables
    *
@@ -112,6 +146,24 @@ public class PipelineRunConfiguration extends HopMetadataBase implements Cloneab
     this.engineRunConfiguration = engineRunConfiguration;
   }
 
+  /**
+   * Gets executionDataProfileName
+   *
+   * @return value of executionDataProfileName
+   */
+  public String getExecutionDataProfileName() {
+    return executionDataProfileName;
+  }
+
+  /**
+   * Sets executionDataProfileName
+   *
+   * @param executionDataProfileName value of executionDataProfileName
+   */
+  public void setExecutionDataProfileName(String executionDataProfileName) {
+    this.executionDataProfileName = executionDataProfileName;
+  }
+
   public void applyToVariables(IVariables variables) {
     for (DescribedVariable vvd : configurationVariables) {
       if (StringUtils.isNotEmpty(vvd.getName())) {
