@@ -159,7 +159,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
     //
     if (systemProperties != null) {
       for (String parameter : systemProperties) {
-        String[] split = parameter.split("=");
+        String[] split = parameter.split("=", 2);
         String key = split.length > 0 ? split[0] : null;
         String value = split.length > 1 ? split[1] : null;
         if (StringUtils.isNotEmpty(key) && StringUtils.isNotEmpty(value)) {
@@ -169,6 +169,18 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
     }
   }
 
+  private void prepareInternalOptions(CommandLine cmd, String[] args) {
+    for (String arg : args) {
+      if (arg.startsWith("-h") || arg.startsWith("--help")) {
+        return;
+      }
+    }
+    String[] helpArgs = new String[args.length + 1];
+    System.arraycopy(args, 0, helpArgs, 0, args.length);
+    helpArgs[args.length] = "-h";
+    cmd.parseArgs(helpArgs);
+  }
+
   private void buildVariableSpace() throws IOException {
     // Also grabs the system properties from hop.config.
     //
@@ -182,7 +194,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
 
       // Run the pipeline with the given filename
       //
-      PipelineMeta pipelineMeta = new PipelineMeta(realFilename, metadataProvider, true, variables);
+      PipelineMeta pipelineMeta = new PipelineMeta(realFilename, metadataProvider, variables);
 
       // Configure the basic execution settings
       //
@@ -247,7 +259,7 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       pipeline.startThreads();
       pipeline.waitUntilFinished();
       // TODO: how to see if a pipeline fails? getresult always return true
-      setFinishedWithoutError(true);
+      setFinishedWithoutError(pipeline.getResult().getNrErrors() == 0l);
     } catch (Exception e) {
       throw new ExecutionException(cmd, "Error running pipeline locally", e);
     }
@@ -391,9 +403,12 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       String[] availableParameters = namedParams.listParameters();
       if (parameters != null) {
         for (String parameter : parameters) {
-          String[] split = parameter.split("=");
+          String[] split = parameter.split("=", 2);
           String key = split.length > 0 ? split[0] : null;
           String value = split.length > 1 ? split[1] : null;
+          if (value != null && value.startsWith("\"") && value.endsWith("\"")) {
+            value = value.substring(1, value.length() - 1);
+          }
 
           if (key != null) {
             // We can work with this.
@@ -726,6 +741,9 @@ public class HopRun implements Runnable, IHasHopMetadataProvider {
       //
       CommandLine cmd = new CommandLine(hopRun);
 
+      if (args.length > 0) {
+        hopRun.prepareInternalOptions(new CommandLine(hopRun), args);
+      }
       // Apply the system properties to the JVM
       //
       hopRun.applySystemProperties();
