@@ -64,6 +64,8 @@ import java.io.*;
 import java.net.URLEncoder;
 import java.text.MessageFormat;
 import java.util.*;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 @HopMetadata(
     key = "server",
@@ -237,10 +239,13 @@ public class HopServer extends HopMetadataBase implements Cloneable, IXml, IHopM
   }
 
   @Override
-  public Object clone() {
-    HopServer hopServer = new HopServer();
-    hopServer.replaceMeta(this);
-    return hopServer;
+  public HopServer clone() {
+    return new HopServer(this);
+  }
+
+  public HopServer(HopServer server) {
+    this();
+    replaceMeta(server);
   }
 
   public void replaceMeta(HopServer hopServer) {
@@ -436,9 +441,16 @@ public class HopServer extends HopMetadataBase implements Cloneable, IXml, IHopM
     return result;
   }
 
-  // Method is defined as package-protected in order to be accessible by unit tests
   HttpPost buildSendXmlMethod(IVariables variables, byte[] content, String service)
       throws Exception {
+    String encoding = Const.getEnvironmentVariable("file.encoding", Const.XML_ENCODING);
+    return buildSendMethod(variables, content, encoding, service, "text/xml");
+  }
+
+  // Method is defined as package-protected in order to be accessible by unit tests
+  HttpPost buildSendMethod(
+      IVariables variables, byte[] content, String encoding, String service, String contentType)
+      throws Exception {
     // Prepare HTTP put
     //
     String urlString = constructUrl(variables, service);
@@ -452,13 +464,15 @@ public class HopServer extends HopMetadataBase implements Cloneable, IXml, IHopM
     HttpEntity entity = new ByteArrayEntity(content);
 
     postMethod.setEntity(entity);
-    postMethod.addHeader(new BasicHeader("Content-Type", "text/xml;charset=" + Const.XML_ENCODING));
+    postMethod.addHeader(new BasicHeader("Content-Type", contentType + ";charset=" + encoding));
 
     return postMethod;
   }
 
   public String sendXml(IVariables variables, String xml, String service) throws Exception {
-    HttpPost method = buildSendXmlMethod(variables, xml.getBytes(Const.XML_ENCODING), service);
+    String encoding = getXmlEncoding(xml);
+    HttpPost method =
+        buildSendMethod(variables, xml.getBytes(encoding), encoding, service, "text/xml");
     try {
       return executeAuth(variables, method);
     } finally {
@@ -472,6 +486,32 @@ public class HopServer extends HopMetadataBase implements Cloneable, IXml, IHopM
     }
   }
 
+  public String sendJson(IVariables variables, String json, String service) throws Exception {
+    String encoding = Const.XML_ENCODING;
+    HttpPost method =
+        buildSendMethod(variables, json.getBytes(encoding), encoding, service, "application/json");
+    try {
+      return executeAuth(variables, method);
+    } finally {
+      // Release current connection to the connection pool once you are done
+      method.releaseConnection();
+      if (log.isDetailed()) {
+        log.logDetailed(
+            BaseMessages.getString(
+                PKG, "HopServer.DETAILED_SentXmlToService", service, variables.resolve(hostname)));
+      }
+    }
+  }
+
+  private String getXmlEncoding(String xml) {
+    Pattern xmlHeadPattern = Pattern.compile("<\\?xml.* encoding=\"(.*)\"");
+    Matcher matcher = xmlHeadPattern.matcher(xml);
+    if (matcher.find()) {
+      return matcher.group();
+    }
+    return Const.getEnvironmentVariable("file.encoding", Const.XML_ENCODING);
+  }
+
   /** Throws if not ok */
   private void handleStatus(
       IVariables variables, HttpUriRequest method, StatusLine statusLine, int status)
