@@ -17,7 +17,6 @@
 
 package org.apache.hop.www;
 
-import com.sun.jersey.spi.container.servlet.ServletContainer;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.HopEnvironment;
 import org.apache.hop.core.encryption.Encr;
@@ -47,8 +46,10 @@ import org.eclipse.jetty.util.resource.PathResource;
 import org.eclipse.jetty.util.security.Constraint;
 import org.eclipse.jetty.util.security.Password;
 import org.eclipse.jetty.util.ssl.SslContextFactory;
+import org.glassfish.jersey.servlet.ServletContainer;
 
 import javax.servlet.Servlet;
+import java.awt.GraphicsEnvironment;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.List;
@@ -218,6 +219,7 @@ public class WebServer {
     rootServlet.setJettyMode(true);
     root.addServlet(new ServletHolder(rootServlet), "/*");
 
+    boolean graphicsEnvironment = supportGraphicEnvironment();
     PluginRegistry pluginRegistry = PluginRegistry.getInstance();
     List<IPlugin> plugins = pluginRegistry.getPlugins(HopServerPluginType.class);
     for (IPlugin plugin : plugins) {
@@ -231,6 +233,7 @@ public class WebServer {
               contexts, getContextPath(servlet), ServletContextHandler.SESSIONS);
       ServletHolder servletHolder = new ServletHolder((Servlet) servlet);
       servletContext.addServlet(servletHolder, "/*");
+      servletContext.setAttribute("GraphicsEnvironment", graphicsEnvironment);
     }
 
     // setup jersey (REST)
@@ -511,4 +514,12 @@ public class WebServer {
       return DEFAULT_DETECTION_TIMER;
     }
   }
+
+  private boolean supportGraphicEnvironment() {
+    try {
+      return GraphicsEnvironment.getLocalGraphicsEnvironment() != null;
+    } catch (Error ignored) {
+    }
+    return false;
+  }
 }
