@@ -130,27 +130,6 @@ public class PipelineMetaTest {
     assertEquals(overriddenValue, thisTransformsFields.getValueMeta(0).getName());
   }
 
-  @Test
-  public void getThisTransformFieldsPassesClonedInfoRowMeta() throws Exception {
-    // given
-    ITransformMeta smi = mock(ITransformMeta.class);
-    TransformIOMeta ioMeta = mock(TransformIOMeta.class);
-    when(smi.getTransformIOMeta()).thenReturn(ioMeta);
-
-    TransformMeta thisTransform = mockTransformMeta("thisTransform");
-    TransformMeta nextTransform = mockTransformMeta("nextTransform");
-    when(thisTransform.getTransform()).thenReturn(smi);
-
-    RowMeta row = new RowMeta();
-    when(smi.getTableFields(variables)).thenReturn(row);
-
-    // when
-    pipelineMeta.getThisTransformFields(variables, thisTransform, nextTransform, row);
-
-    // then
-    verify(smi, never()).getFields(any(), any(), eq(new IRowMeta[] {row}), any(), any(), any());
-  }
-
   @Test
   public void testContentChangeListener() throws Exception {
     IContentChangedListener listener = mock(IContentChangedListener.class);
@@ -382,7 +361,7 @@ public class PipelineMetaTest {
     IVariables variables = Mockito.mock(IVariables.class);
     Mockito.when(variables.getVariableNames()).thenReturn(new String[0]);
 
-    meta.loadXml(workflowNode, null, metadataProvider, false, variables);
+    meta.loadXml(workflowNode, null, metadataProvider, variables);
     meta.setInternalHopVariables(variables);
   }
 
