@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -33,17 +32,15 @@ import org.apache.hop.workflow.action.IActionDialog;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
-import org.eclipse.swt.layout.FormAttachment;
-import org.eclipse.swt.layout.FormData;
-import org.eclipse.swt.layout.FormLayout;
+import org.eclipse.swt.events.SelectionListener;
+import org.eclipse.swt.layout.*;
 import org.eclipse.swt.widgets.*;
 
+
 /** This dialog allows you to edit a Action Abort object. */
 public class ActionAbortDialog extends ActionDialog implements IActionDialog {
   private static final Class<?> PKG = ActionAbortDialog.class; // For Translator
 
-  private Shell shell;
-
   private ActionAbort action;
 
   private boolean changed;
@@ -52,6 +49,8 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
 
   private TextVar wMessageAbort;
 
+  private Button wAlwaysLogRows;
+
   public ActionAbortDialog(
       Shell parent, IAction action, WorkflowMeta workflowMeta, IVariables variables) {
     super(parent, workflowMeta, variables);
@@ -75,6 +74,7 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     FormLayout formLayout = new FormLayout();
     formLayout.marginWidth = Const.FORM_MARGIN;
     formLayout.marginHeight = Const.FORM_MARGIN;
+    formLayout.spacing = Const.FORM_MARGIN;
 
     shell.setLayout(formLayout);
     shell.setText(BaseMessages.getString(PKG, "ActionAbortDialog.Title"));
@@ -121,6 +121,21 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     fdMessageAbort.right = new FormAttachment(100, 0);
     wMessageAbort.setLayoutData(fdMessageAbort);
 
+    SelectionListener slMod = SelectionListener.widgetSelectedAdapter(event -> action.setChanged());
+    // Always log rows
+    wAlwaysLogRows = new Button(shell, SWT.CHECK);
+    wAlwaysLogRows.setSelection(true);
+    props.setLook(wAlwaysLogRows);
+    wAlwaysLogRows.setText(BaseMessages.getString(PKG, "ActionAbortDialog.AlwaysLogRows.Label"));
+    wAlwaysLogRows.setToolTipText(
+        BaseMessages.getString(PKG, "ActionAbortDialog.AlwaysLogRows.Tooltip"));
+    wAlwaysLogRows.addSelectionListener(slMod);
+    FormData fdAlwaysLogRows = new FormData();
+    fdAlwaysLogRows.left = new FormAttachment(middle, 0);
+    fdAlwaysLogRows.top = new FormAttachment(wMessageAbort, margin);
+    fdAlwaysLogRows.right = new FormAttachment(100, 0);
+    wAlwaysLogRows.setLayoutData(fdAlwaysLogRows);
+
     Button wOk = new Button(shell, SWT.PUSH);
     wOk.setText(BaseMessages.getString(PKG, "System.Button.OK"));
     wOk.addListener(SWT.Selection, (Event e) -> ok());
@@ -128,7 +143,7 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     wCancel.setText(BaseMessages.getString(PKG, "System.Button.Cancel"));
     wCancel.addListener(SWT.Selection, (Event e) -> cancel());
     BaseTransformDialog.positionBottomButtons(
-        shell, new Button[] {wOk, wCancel}, margin, wMessageAbort);
+        shell, new Button[] {wOk, wCancel}, margin, 0, wAlwaysLogRows);
 
     getData();
 
@@ -137,12 +152,6 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
@@ -151,6 +160,7 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     if (action.getMessageAbort() != null) {
       wMessageAbort.setText(action.getMessageAbort());
     }
+    wAlwaysLogRows.setSelection(action.isAlwaysLogRows());
 
     wName.selectAll();
     wName.setFocus();
@@ -172,6 +182,7 @@ public class ActionAbortDialog extends ActionDialog implements IActionDialog {
     }
     action.setName(wName.getText());
     action.setMessageAbort(wMessageAbort.getText());
+    action.setAlwaysLogRows(wAlwaysLogRows.getSelection());
     dispose();
   }
 }
