@@ -23,7 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -61,7 +60,6 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
   private Button wDeleteAllBefore;
 
   private ActionAddResultFilenames action;
-  private Shell shell;
 
   private boolean changed;
 
@@ -463,12 +461,6 @@ public class ActionAddResultFilenamesDialog extends ActionDialog implements IAct
     wbDirectory.setEnabled(!wPrevious.getSelection());
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
