@@ -23,7 +23,6 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.FormDataBuilder;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -44,8 +43,6 @@ import org.eclipse.swt.widgets.*;
 public class ActionAs400CommandDialog extends ActionDialog implements IActionDialog {
   private static final Class<?> PKG = ActionAs400CommandDialog.class; // For Translator
 
-  private Shell shell;
-
   private ActionAs400Command action;
 
   private boolean changed;
@@ -245,12 +242,6 @@ public class ActionAs400CommandDialog extends ActionDialog implements IActionDia
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
