@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -49,7 +48,6 @@ public class ActionDelayDialog extends ActionDialog implements IActionDialog {
   private LabelTextVar wMaximumTimeout;
 
   private ActionDelay action;
-  private Shell shell;
 
   private boolean changed;
 
@@ -152,12 +150,6 @@ public class ActionDelayDialog extends ActionDialog implements IActionDialog {
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
