@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -49,8 +48,6 @@ public class ActionDeleteFilesDialog extends ActionDialog implements IActionDial
   private static final String[] FILETYPES =
       new String[] {BaseMessages.getString(PKG, "ActionDeleteFiles.Filetype.All")};
 
-  private Shell shell;
-
   private Text wName;
 
   private Label wlFilename;
@@ -432,12 +429,6 @@ public class ActionDeleteFilesDialog extends ActionDialog implements IActionDial
     wbDirectory.setEnabled(!wPrevious.getSelection());
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
