@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -54,7 +53,6 @@ public class ActionDeleteResultFilenamesDialog extends ActionDialog implements I
   private TextVar wWildcardExclude;
 
   private ActionDeleteResultFilenames action;
-  private Shell shell;
 
   private boolean changed;
 
@@ -202,12 +200,6 @@ public class ActionDeleteResultFilenamesDialog extends ActionDialog implements I
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   private void CheckLimit() {
     wlWildcard.setEnabled(wSpecifyWildcard.getSelection());
     wWildcard.setEnabled(wSpecifyWildcard.getSelection());
