@@ -23,7 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.StyledTextComp;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -50,8 +49,6 @@ public class ActionEvalDialog extends ActionDialog implements IActionDialog {
 
   private ActionEval action;
 
-  private Shell shell;
-
   private boolean changed;
 
   public ActionEvalDialog(
@@ -200,12 +197,6 @@ public class ActionEvalDialog extends ActionDialog implements IActionDialog {
             PKG, "ActionEval.Position.Label", "" + lineNumber, "" + columnNumber));
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
