@@ -30,7 +30,6 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.database.dialog.DatabaseExplorerDialog;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.MetaSelectionLine;
 import org.apache.hop.ui.core.widget.StyledTextComp;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -64,8 +63,6 @@ public class ActionEvalTableContentDialog extends ActionDialog implements IActio
 
   private ActionEvalTableContent action;
 
-  private Shell shell;
-
   private boolean changed;
 
   private Label wlUseSubs;
@@ -623,12 +620,6 @@ public class ActionEvalTableContentDialog extends ActionDialog implements IActio
     wSchemaname.setEnabled(!wCustomSql.getSelection());
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
