@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -55,7 +54,6 @@ public class ActionFolderIsEmptyDialog extends ActionDialog implements IActionDi
   private TextVar wWildcard;
 
   private ActionFolderIsEmpty action;
-  private Shell shell;
 
   private boolean changed;
 
@@ -236,12 +234,6 @@ public class ActionFolderIsEmptyDialog extends ActionDialog implements IActionDi
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   private void checkLimitSearch() {
     wlWildcard.setEnabled(wSpecifyWildcard.getSelection());
     wWildcard.setEnabled(wSpecifyWildcard.getSelection());
