@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -54,7 +53,6 @@ public class ActionFoldersCompareDialog extends ActionDialog implements IActionD
   private TextVar wFilename2;
 
   private ActionFoldersCompare action;
-  private Shell shell;
 
   private boolean changed;
 
@@ -408,12 +406,6 @@ public class ActionFoldersCompareDialog extends ActionDialog implements IActionD
     wlCompareFileSize.setEnabled(wCompareOnly.getSelectionIndex() != 2);
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     if (action.getName() != null) {
