@@ -25,7 +25,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelText;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -81,8 +80,6 @@ public class ActionFtpDialog extends ActionDialog implements IActionDialog {
 
   private ActionFtp action;
 
-  private Shell shell;
-
   private Combo wControlEncoding;
 
   private boolean changed;
@@ -1327,9 +1324,7 @@ public class ActionFtpDialog extends ActionDialog implements IActionDialog {
 
   public void dispose() {
     closeFtpConnection();
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
+    super.dispose();
   }
 
   /** Copy information from the meta-data input to the dialog fields. */
