@@ -25,7 +25,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelText;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -76,8 +75,6 @@ public class ActionFtpDeleteDialog extends ActionDialog implements IActionDialog
 
   private ActionFtpDelete action;
 
-  private Shell shell;
-
   private Combo wProtocol;
 
   private Label wlUsePublicKey;
@@ -1127,9 +1124,7 @@ public class ActionFtpDeleteDialog extends ActionDialog implements IActionDialog
 
   public void dispose() {
     closeFtpConnections();
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
+    super.dispose();
   }
 
   /** Copy information from the meta-data input to the dialog fields. */
