@@ -23,7 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.core.widget.PasswordTextVar;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -78,8 +77,6 @@ public class ActionSftpDialog extends ActionDialog implements IActionDialog {
 
   private ActionSftp action;
 
-  private Shell shell;
-
   private boolean changed;
 
   private Button wAddFilenameToResult;
@@ -870,9 +867,7 @@ public class ActionSftpDialog extends ActionDialog implements IActionDialog {
 
   public void dispose() {
     closeFtpConnections();
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
+    super.dispose();
   }
 
   /** Copy information from the meta-data input to the dialog fields. */
