@@ -23,7 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.core.widget.PasswordTextVar;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -76,7 +75,6 @@ public class ActionSftpPutDialog extends ActionDialog implements IActionDialog {
   private TextVar wWildcard;
 
   private ActionSftpPut action;
-  private Shell shell;
 
   private Button wCreateRemoteFolder;
 
@@ -1039,9 +1037,7 @@ public class ActionSftpPutDialog extends ActionDialog implements IActionDialog {
   public void dispose() {
     // Close open connections
     closeFtpConnections();
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
+    super.dispose();
   }
 
   /** Copy information from the meta-data input to the dialog fields. */
