@@ -24,7 +24,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.*;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -77,6 +76,9 @@ public class ActionMailDialog extends ActionDialog implements IActionDialog {
 
   private Button wUseSecAuth;
 
+  private Label wlUseXOAUTH2;
+  private Button wUseXOAUTH2;
+
   private LabelTextVar wAuthUser;
 
   private LabelTextVar wAuthPass;
@@ -125,8 +127,6 @@ public class ActionMailDialog extends ActionDialog implements IActionDialog {
   private Label wlSensitivity;
   private CCombo wSensitivity;
 
-  private Shell shell;
-
   private ActionMail action;
 
   private boolean backupDate;
@@ -495,6 +495,24 @@ public class ActionMailDialog extends ActionDialog implements IActionDialog {
           }
         });
 
+    // USE connection with XOAUTH2
+    wlUseXOAUTH2 = new Label( wAuthentificationGroup, SWT.RIGHT );
+    wlUseXOAUTH2.setText( BaseMessages.getString( PKG, "ActionMail.UseXOAUTH2Mails.Label" ) );
+    props.setLook( wlUseXOAUTH2 );
+    FormData fdlUseXOAUTH2 = new FormData();
+    fdlUseXOAUTH2.left = new FormAttachment( 0, 0 );
+    fdlUseXOAUTH2.top = new FormAttachment( wUseAuth, margin );
+    fdlUseXOAUTH2.right = new FormAttachment( middle, -margin );
+    wlUseXOAUTH2.setLayoutData( fdlUseXOAUTH2 );
+    wUseXOAUTH2 = new Button( wAuthentificationGroup, SWT.CHECK );
+    props.setLook( wUseXOAUTH2 );
+    FormData fdUseXOAUTH2 = new FormData();
+    wUseXOAUTH2.setToolTipText( BaseMessages.getString( PKG, "ActionMail.UseXOAUTH2Mails.Tooltip" ) );
+    fdUseXOAUTH2.left = new FormAttachment( middle, margin );
+    fdUseXOAUTH2.top = new FormAttachment( wlUseXOAUTH2, 0 , SWT.CENTER);
+    fdUseXOAUTH2.right = new FormAttachment( 100, 0 );
+    wUseXOAUTH2.setLayoutData( fdUseXOAUTH2 );
+
     // AuthUser line
     wAuthUser =
         new LabelTextVar(
@@ -505,7 +523,7 @@ public class ActionMailDialog extends ActionDialog implements IActionDialog {
     wAuthUser.addModifyListener(lsMod);
     FormData fdAuthUser = new FormData();
     fdAuthUser.left = new FormAttachment(0, 0);
-    fdAuthUser.top = new FormAttachment(wlUseAuth, 2 * margin);
+    fdAuthUser.top = new FormAttachment(wlUseXOAUTH2, 2 * margin);
     fdAuthUser.right = new FormAttachment(100, 0);
     wAuthUser.setLayoutData(fdAuthUser);
 
@@ -1345,20 +1363,17 @@ public class ActionMailDialog extends ActionDialog implements IActionDialog {
     wAuthPass.setEnabled(wUseAuth.getSelection());
     wUseSecAuth.setEnabled(wUseAuth.getSelection());
     wlUseSecAuth.setEnabled(wUseAuth.getSelection());
+    wlUseXOAUTH2.setEnabled(wUseAuth.getSelection());
+    wUseXOAUTH2.setEnabled(wUseAuth.getSelection());
     if (!wUseAuth.getSelection()) {
       wSecureConnectionType.setEnabled(false);
       wlSecureConnectionType.setEnabled(false);
+      wUseXOAUTH2.setEnabled(false);
     } else {
       setSecureConnectiontype();
     }
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
     wDestination.setText(Const.nullToEmpty(action.getDestination()));
@@ -1372,7 +1387,7 @@ public class ActionMailDialog extends ActionDialog implements IActionDialog {
     wPerson.setText(Const.nullToEmpty(action.getContactPerson()));
     wPhone.setText(Const.nullToEmpty(action.getContactPhone()));
     wComment.setText(Const.nullToEmpty(action.getComment()));
-
+    wUseXOAUTH2.setSelection(action.isUseXOAUTH2());
     wAddDate.setSelection(action.getIncludeDate());
     wIncludeFiles.setSelection(action.isIncludingFiles());
 
@@ -1502,7 +1517,7 @@ public class ActionMailDialog extends ActionDialog implements IActionDialog {
     action.setContactPerson(wPerson.getText());
     action.setContactPhone(wPhone.getText());
     action.setComment(wComment.getText());
-
+    action.setUseXOAUTH2(wUseXOAUTH2.getSelection());
     action.setIncludeDate(wAddDate.getSelection());
     action.setIncludingFiles(wIncludeFiles.getSelection());
     action.setFileType(wTypes.getSelectionIndices());
