@@ -31,7 +31,6 @@ import org.apache.hop.ui.core.database.dialog.DatabaseExplorerDialog;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterSelectionDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.MetaSelectionLine;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
@@ -72,7 +71,7 @@ public class ActionMssqlBulkLoadDialog extends ActionDialog implements IActionDi
   private TextVar wTablename;
 
   private ActionMssqlBulkLoad action;
-  private Shell shell;
+
   private boolean changed;
 
   private TextVar wFilename;
@@ -1026,12 +1025,6 @@ public class ActionMssqlBulkLoadDialog extends ActionDialog implements IActionDi
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   private void setDataType() {
     if (wDataFiletype.getSelectionIndex() == 0 || wDataFiletype.getSelectionIndex() == 2) {
       wFieldTerminator.setEnabled(true);
