@@ -30,7 +30,6 @@ import org.apache.hop.ui.core.database.dialog.DatabaseExplorerDialog;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterSelectionDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.MetaSelectionLine;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
@@ -68,7 +67,7 @@ public class ActionMysqlBulkLoadDialog extends ActionDialog implements IActionDi
   private TextVar wTablename;
 
   private ActionMysqlBulkLoad action;
-  private Shell shell;
+
   private boolean changed;
 
   private TextVar wFilename;
@@ -551,12 +550,6 @@ public class ActionMysqlBulkLoadDialog extends ActionDialog implements IActionDi
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
