@@ -23,7 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -65,7 +64,6 @@ public class ActionPGPEncryptFilesDialog extends ActionDialog implements IAction
   private Button wIncludeSubfolders;
 
   private ActionPGPEncryptFiles action;
-  private Shell shell;
 
   private boolean changed;
 
@@ -1501,12 +1499,6 @@ public class ActionPGPEncryptFilesDialog extends ActionDialog implements IAction
     wbDestinationDirectory.setEnabled(!wPrevious.getSelection());
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   private void checkIncludeSubFolders() {
     wlDoNotKeepFolderStructure.setEnabled(wIncludeSubfolders.getSelection());
     wDoNotKeepFolderStructure.setEnabled(wIncludeSubfolders.getSelection());
