@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -53,8 +52,6 @@ public class ActionPingDialog extends ActionDialog implements IActionDialog {
 
   private ActionPing action;
 
-  private Shell shell;
-
   private CCombo wPingType;
 
   private Label wlNbrPackets;
@@ -234,12 +231,6 @@ public class ActionPingDialog extends ActionDialog implements IActionDialog {
             || wPingType.getSelectionIndex() == action.ibothPings);
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
