@@ -157,6 +157,8 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
       return prevResult;
     }
 
+    // Also check the variable in the workflow
+
     ExecutionResult executionResult = null;
 
     boolean repeat = true;
@@ -164,7 +166,7 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
     while (repeat && !parentWorkflow.isStopped()) {
       repetitionNr++;
       executionResult =
-          executeTransformationOrWorkflow(realFilename, nr, executionResult, repetitionNr);
+          executePipelineOrWorkflow(realFilename, nr, executionResult, repetitionNr);
       Result result = executionResult.result;
       if (!result.getResult() || result.getNrErrors() > 0 || result.isStopped()) {
         log.logError(
@@ -181,7 +183,7 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
         if (executionResult.flagSet) {
           repeat = false;
         } else {
-          // Repeat as long as the variable is not set.
+          // Repeat as long as the variable is not set in the child workflow or pipeline
           //
           repeat = !isVariableValueSet(executionResult.variables);
         }
@@ -211,7 +213,7 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
     return prevResult;
   }
 
-  private ExecutionResult executeTransformationOrWorkflow(
+  private ExecutionResult executePipelineOrWorkflow(
       String realFilename, int nr, ExecutionResult previousResult, int repetitionNr)
       throws HopException {
     if (isPipeline(realFilename)) {
@@ -229,7 +231,7 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
     PipelineMeta pipelineMeta = loadPipeline(realFilename, getMetadataProvider(), this);
     IPipelineEngine<PipelineMeta> pipeline =
         PipelineEngineFactory.createPipelineEngine(
-            this, runConfigurationName, getMetadataProvider(), pipelineMeta);
+            this, resolve(runConfigurationName), getMetadataProvider(), pipelineMeta);
     pipeline.setParentWorkflow(getParentWorkflow());
     pipeline.setParent(this);
     if (keepingValues && previousResult != null) {
@@ -242,7 +244,10 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
       pipeline.copyParametersFromDefinitions(pipelineMeta);
     }
     pipeline.getPipelineMeta().setInternalHopVariables(pipeline);
-    pipeline.setVariables(getVariablesMap(pipeline, previousResult));
+
+    // A pipeline can only change variables in the parent workflow
+    // So let's take the workflow variables to evaluate.
+    pipeline.setVariables(getVariablesMap(getParentWorkflow(), previousResult));
 
     // TODO: check this!
     INamedParameters previousParams =
@@ -336,7 +341,7 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
     WorkflowMeta workflowMeta = loadWorkflow(realFilename, getMetadataProvider(), this);
     IWorkflowEngine<WorkflowMeta> workflow =
         WorkflowEngineFactory.createWorkflowEngine(
-            this, runConfigurationName, getMetadataProvider(), workflowMeta, this);
+            this, resolve(runConfigurationName), getMetadataProvider(), workflowMeta, this);
     workflow.setParentWorkflow(getParentWorkflow());
     workflow.setParentVariables(this);
     if (keepingValues && previousResult != null) {
@@ -592,7 +597,7 @@ public class Repeat extends ActionBase implements IAction, Cloneable {
   private PipelineMeta loadPipeline(
       String realFilename, IHopMetadataProvider metadataProvider, IVariables variables)
       throws HopException {
-    PipelineMeta pipelineMeta = new PipelineMeta(realFilename, metadataProvider, true, variables);
+    PipelineMeta pipelineMeta = new PipelineMeta(realFilename, metadataProvider, variables);
     return pipelineMeta;
   }
 
