@@ -24,7 +24,6 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelText;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.core.widget.StyledTextComp;
@@ -64,8 +63,6 @@ public class ActionSendNagiosPassiveCheckDialog extends ActionDialog implements
 
   private ActionSendNagiosPassiveCheck action;
 
-  private Shell shell;
-
   private boolean changed;
 
   private LabelTextVar wPort;
@@ -474,12 +471,6 @@ public class ActionSendNagiosPassiveCheckDialog extends ActionDialog implements
     }
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
