@@ -22,7 +22,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -51,7 +50,6 @@ public class ActionSetVariablesDialog extends ActionDialog implements IActionDia
   private Button wVarSubs;
 
   private ActionSetVariables action;
-  private Shell shell;
 
   private TableView wFields;
 
@@ -275,12 +273,6 @@ public class ActionSetVariablesDialog extends ActionDialog implements IActionDia
     return action;
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
