@@ -24,7 +24,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.TableView;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -100,8 +99,6 @@ public class ActionShellDialog extends ActionDialog implements IActionDialog {
 
   private TableView wFields;
 
-  private Shell shell;
-
   private ActionShell action;
 
   private boolean backupChanged;
@@ -655,12 +652,6 @@ public class ActionShellDialog extends ActionDialog implements IActionDialog {
     }
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   public void setActive() {
     wlLogfile.setEnabled(action.setLogfile);
     wLogfile.setEnabled(action.setLogfile);
