@@ -23,7 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.LabelText;
 import org.apache.hop.ui.core.widget.LabelTextVar;
 import org.apache.hop.ui.core.widget.StyledTextComp;
@@ -71,8 +70,6 @@ public class ActionSNMPTrapDialog extends ActionDialog implements IActionDialog
 
   private ActionSNMPTrap action;
 
-  private Shell shell;
-
   private boolean changed;
 
   private LabelTextVar wPort;
@@ -490,12 +487,6 @@ public class ActionSNMPTrapDialog extends ActionDialog implements IActionDialog
     }
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
