@@ -27,7 +27,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterSelectionDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ColumnInfo;
 import org.apache.hop.ui.core.widget.MetaSelectionLine;
 import org.apache.hop.ui.core.widget.TableView;
@@ -56,8 +55,6 @@ import java.util.Arrays;
 public class ActionTruncateTablesDialog extends ActionDialog implements IActionDialog {
   private static final Class<?> PKG = ActionTruncateTables.class; // For Translator
 
-  private Shell shell;
-
   private Button wbTable;
 
   private Text wName;
@@ -270,11 +267,6 @@ public class ActionTruncateTablesDialog extends ActionDialog implements IActionD
     wbTable.setEnabled(!wPrevious.getSelection());
   }
 
-  public void dispose() {
-    props.setScreen(new WindowProperty(shell));
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
