@@ -23,7 +23,6 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
@@ -62,7 +61,6 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
   private TextVar wZipFilename;
 
   private ActionUnZip action;
-  private Shell shell;
 
   private TextVar wTargetDirectory;
 
@@ -995,12 +993,6 @@ public class ActionUnZipDialog extends ActionDialog implements IActionDialog {
     wlWildcardSource.setEnabled(!wArgsPrevious.getSelection());
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
