@@ -30,7 +30,6 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.database.dialog.DatabaseExplorerDialog;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.MetaSelectionLine;
 import org.apache.hop.ui.core.widget.StyledTextComp;
 import org.apache.hop.ui.core.widget.TextVar;
@@ -61,8 +60,6 @@ public class ActionWaitForSqlDialog extends ActionDialog implements IActionDialo
 
   private ActionWaitForSql action;
 
-  private Shell shell;
-
   private boolean changed;
 
   private Label wlUseSubs;
@@ -682,12 +679,6 @@ public class ActionWaitForSqlDialog extends ActionDialog implements IActionDialo
     wSchemaname.setEnabled(!wCustomSql.getSelection());
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
