@@ -24,7 +24,6 @@ import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
 import org.apache.hop.ui.core.dialog.EnterSelectionDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.ComboVar;
 import org.apache.hop.ui.core.widget.TextVar;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
@@ -67,8 +66,6 @@ public class ActionZipFileDialog extends ActionDialog implements IActionDialog {
 
   private ActionZipFile action;
 
-  private Shell shell;
-
   private Label wlSourceDirectory;
 
   private TextVar wSourceDirectory;
@@ -972,12 +969,6 @@ public class ActionZipFileDialog extends ActionDialog implements IActionDialog {
     }
   }
 
-  public void dispose() {
-    WindowProperty winprop = new WindowProperty(shell);
-    props.setScreen(winprop);
-    shell.dispose();
-  }
-
   /** Copy information from the meta-data input to the dialog fields. */
   public void getData() {
     wName.setText(Const.nullToEmpty(action.getName()));
