@@ -147,7 +147,7 @@ public class MySqlDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
       case "Mysql":
         return "org.gjt.mm.mysql.Driver";
       case "Mysql 8+":
-        return "com.mysql.jdbc.Driver";
+        return "com.mysql.cj.jdbc.Driver";
       default:
         return "org.gjt.mm.mysql.Driver";
     }
@@ -705,6 +705,8 @@ public class MySqlDatabaseMeta extends BaseDatabaseMeta implements IDatabase {
   public void addDefaultOptions() {
     addExtraOption(getPluginId(), "defaultFetchSize", "500");
     addExtraOption(getPluginId(), "useCursorFetch", "true");
+    addExtraOption(getPluginId(), "zeroDateTimeBehaviorValue", "CONVERT_TO_NULL");
+
   }
 
   @Override
