@@ -32,7 +32,7 @@ import org.apache.commons.lang.StringUtils;
 import org.apache.hop.beam.core.BeamHop;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.fn.HopToBQTableRowFn;
-import org.apache.hop.beam.core.util.JsonRowMeta;
+import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
@@ -41,7 +41,6 @@ import org.slf4j.LoggerFactory;
 
 import java.util.ArrayList;
 import java.util.List;
-import java.util.Locale;
 
 public class BeamBQOutputTransform extends PTransform<PCollection<HopRow>, PDone> {
 
@@ -130,6 +129,9 @@ public class BeamBQOutputTransform extends PTransform<PCollection<HopRow>, PDone
           case IValueMeta.TYPE_NUMBER:
             schemaField.setType("FLOAT");
             break;
+          case IValueMeta.TYPE_TIMESTAMP:
+            schemaField.setType("TIMESTAMP");
+            break;
           default:
             throw new RuntimeException(
                 "Conversion from Hop value "
