@@ -19,7 +19,6 @@ package org.apache.hop.beam.core.transform;
 
 import org.apache.beam.sdk.metrics.Counter;
 import org.apache.beam.sdk.metrics.Metrics;
-import org.apache.beam.sdk.transforms.DoFn;
 import org.apache.beam.sdk.transforms.ParDo;
 import org.apache.beam.sdk.transforms.windowing.BoundedWindow;
 import org.apache.beam.sdk.values.*;
@@ -28,7 +27,8 @@ import org.apache.hop.beam.core.BeamHop;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.shared.VariableValue;
 import org.apache.hop.beam.core.util.HopBeamUtil;
-import org.apache.hop.beam.core.util.JsonRowMeta;
+import org.apache.hop.core.row.JsonRowMeta;
+import org.apache.hop.beam.engines.HopPipelineExecutionOptions;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.exception.HopTransformException;
 import org.apache.hop.core.logging.LogLevel;
@@ -38,7 +38,13 @@ import org.apache.hop.core.plugins.PluginRegistry;
 import org.apache.hop.core.plugins.TransformPluginType;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.IValueMeta;
+import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.core.variables.Variables;
+import org.apache.hop.execution.ExecutionDataBuilder;
+import org.apache.hop.execution.ExecutionInfoLocation;
+import org.apache.hop.execution.ExecutionType;
+import org.apache.hop.execution.sampler.IExecutionDataSampler;
+import org.apache.hop.execution.sampler.IExecutionDataSamplerStore;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.*;
 import org.apache.hop.pipeline.engines.local.LocalPipelineEngine;
@@ -46,7 +52,6 @@ import org.apache.hop.pipeline.transform.*;
 import org.apache.hop.pipeline.transforms.dummy.DummyMeta;
 import org.apache.hop.pipeline.transforms.injector.InjectorField;
 import org.apache.hop.pipeline.transforms.injector.InjectorMeta;
-import org.joda.time.Instant;
 
 import java.util.*;
 import java.util.concurrent.ConcurrentLinkedQueue;
@@ -73,7 +78,10 @@ public class TransformBatchTransform extends TransformTransform {
       List<String> targetTransforms,
       List<String> infoTransforms,
       List<String> infoRowMetaJsons,
-      List<PCollectionView<List<HopRow>>> infoCollectionViews) {
+      List<PCollectionView<List<HopRow>>> infoCollectionViews,
+      String runConfigName,
+      String dataSamplersJson,
+      String parentLogChannelId) {
     super(
         variableValues,
         metastoreJson,
@@ -89,7 +97,10 @@ public class TransformBatchTransform extends TransformTransform {
         targetTransforms,
         infoTransforms,
         infoRowMetaJsons,
-        infoCollectionViews);
+        infoCollectionViews,
+        runConfigName,
+        dataSamplersJson,
+        parentLogChannelId);
   }
 
   @Override
@@ -99,10 +110,10 @@ public class TransformBatchTransform extends TransformTransform {
       //
       BeamHop.init(transformPluginClasses, xpPluginClasses);
 
-      // Similar for the output : treate a TupleTag list for the target transforms...
+      // Similar for the output : treat a TupleTag list for the target transforms...
       //
       TupleTag<HopRow> mainOutputTupleTag =
-          new TupleTag<HopRow>(HopBeamUtil.createMainOutputTupleId(transformName)) {};
+          new TupleTag<>(HopBeamUtil.createMainOutputTupleId(transformName)) {};
       List<TupleTag<HopRow>> targetTupleTags = new ArrayList<>();
       TupleTagList targetTupleTagList = null;
       for (String targetTransform : targetTransforms) {
@@ -134,7 +145,10 @@ public class TransformBatchTransform extends TransformTransform {
               inputTransform,
               targetTransforms,
               infoTransforms,
-              infoRowMetaJsons);
+              infoRowMetaJsons,
+              parentLogChannelId,
+              runConfigName,
+              dataSamplersJson);
 
       // The actual transform functionality
       //
@@ -167,7 +181,7 @@ public class TransformBatchTransform extends TransformTransform {
     }
   }
 
-  private class TransformBatchFn extends DoFn<HopRow, HopRow> {
+  private class TransformBatchFn extends TransformBaseFn {
 
     private static final long serialVersionUID = 95700000000000002L;
 
@@ -177,7 +191,6 @@ public class TransformBatchTransform extends TransformTransform {
     protected String metastoreJson;
     protected List<String> transformPluginClasses;
     protected List<String> xpPluginClasses;
-    protected String transformName;
     protected String transformPluginId;
     protected String transformMetaInterfaceXml;
     protected String inputRowMetaJson;
@@ -217,12 +230,18 @@ public class TransformBatchTransform extends TransformTransform {
     private transient SingleThreadedPipelineExecutor executor;
 
     private transient Queue<HopRow> rowBuffer;
-    private transient BoundedWindow batchWindow;
 
     private transient AtomicLong lastTimerCheck;
     private transient Timer timer;
 
-    public TransformBatchFn() {}
+    private transient ExecutionInfoLocation executionInfoLocation;
+    private transient List<IExecutionDataSampler> dataSamplers;
+    private transient List<IExecutionDataSamplerStore> dataSamplerStores;
+    private transient Timer executionInfoTimer;
+
+    public TransformBatchFn() {
+      super(null, null, null);
+    }
 
     // I created a private class because instances of this one need access to infoCollectionViews
     //
@@ -239,8 +258,11 @@ public class TransformBatchTransform extends TransformTransform {
         boolean inputTransform,
         List<String> targetTransforms,
         List<String> infoTransforms,
-        List<String> infoRowMetaJsons) {
-      this();
+        List<String> infoRowMetaJsons,
+        String parentLogChannelId,
+        String runConfigName,
+        String dataSamplersJson) {
+      super(parentLogChannelId, runConfigName, dataSamplersJson);
       this.variableValues = variableValues;
       this.metastoreJson = metastoreJson;
       this.transformPluginClasses = transformPluginClasses;
@@ -285,6 +307,44 @@ public class TransformBatchTransform extends TransformTransform {
       if (timer != null) {
         timer.cancel();
       }
+      try {
+        if (executor != null) {
+          executor.dispose();
+
+          // Send last data from the data samplers over to the location (if any)
+          //
+          if (executionInfoLocation != null) {
+            if (executionInfoTimer != null) {
+              executionInfoTimer.cancel();
+            }
+            sendSamplesToLocation(true);
+
+            // Close the location
+            //
+            executionInfoLocation.getExecutionInfoLocation().close();
+          }
+        }
+      } catch (Exception e) {
+        throw new RuntimeException(
+            "Error cleaning up single threaded pipeline executor in Beam transform "
+                + transformName,
+            e);
+      }
+    }
+
+    protected void sendSamplesToLocation(boolean finished) throws HopException {
+      ExecutionDataBuilder dataBuilder =
+          ExecutionDataBuilder.of()
+              .withOwnerId(executor.getPipeline().getLogChannelId())
+              .withParentId(parentLogChannelId)
+              .withCollectionDate(new Date())
+              .withFinished(finished)
+              .withExecutionType(ExecutionType.Transform);
+      for (IExecutionDataSamplerStore store : dataSamplerStores) {
+        dataBuilder =
+            dataBuilder.addDataSets(store.getSamples()).addSetMeta(store.getSamplesMetadata());
+      }
+      executionInfoLocation.getExecutionInfoLocation().registerData(dataBuilder.build());
     }
 
     @ProcessElement
@@ -302,11 +362,18 @@ public class TransformBatchTransform extends TransformTransform {
           // The content of the metadata is JSON serialized and inflated below.
           //
           IHopMetadataProvider metadataProvider = new SerializableMetadataProvider(metastoreJson);
+          IVariables variables = new Variables();
+          for (VariableValue variableValue : variableValues) {
+            if (StringUtils.isNotEmpty(variableValue.getVariable())) {
+              variables.setVariable(variableValue.getVariable(), variableValue.getValue());
+            }
+          }
 
           // Create a very simple new transformation to run single threaded...
           // Single threaded...
           //
           pipelineMeta = new PipelineMeta();
+          pipelineMeta.setName(transformName);
           pipelineMeta.setPipelineType(PipelineMeta.PipelineType.SingleThreaded);
           pipelineMeta.setMetadataProvider(metadataProvider);
 
@@ -415,25 +482,21 @@ public class TransformBatchTransform extends TransformTransform {
             pipelineMeta.addPipelineHop(new PipelineHopMeta(infoTransformMeta, transformMeta));
           }
 
+          lookupExecutionInformation(variables, metadataProvider);
+
           iTransformMeta.searchInfoAndTargetTransforms(pipelineMeta.getTransforms());
 
           // Create the transformation...
           //
           pipeline =
               new LocalPipelineEngine(
-                  pipelineMeta,
-                  Variables.getADefaultVariableSpace(),
-                  new LoggingObject("apache-beam-transform"));
-          pipeline.setLogLevel(LogLevel.ERROR);
+                  pipelineMeta, variables, new LoggingObject("apache-beam-transform"));
+          pipeline.setLogLevel(
+              context.getPipelineOptions().as(HopPipelineExecutionOptions.class).getLogLevel());
           pipeline.setMetadataProvider(pipelineMeta.getMetadataProvider());
-
-          // Give transforms variables from above
-          //
-          for (VariableValue variableValue : variableValues) {
-            if (StringUtils.isNotEmpty(variableValue.getVariable())) {
-              pipeline.setVariable(variableValue.getVariable(), variableValue.getValue());
-            }
-          }
+          pipeline
+              .getPipelineRunConfiguration()
+              .setName("beam-batch-transform-local (" + transformName + ")");
 
           pipeline.prepareExecution();
 
@@ -507,6 +570,18 @@ public class TransformBatchTransform extends TransformTransform {
                 });
           }
 
+          // If we're sending execution information to a location we should do it differently from a
+          // Beam node.
+          // We're only going to go through the effort if we actually have any rows to sample.
+          //
+          attachExecutionSamplersToOutput(
+              variables,
+              transformName,
+              pipeline.getLogChannelId(),
+              inputRowMeta,
+              outputRowMeta,
+              pipeline.getTransform(transformName, 0));
+
           executor = new SingleThreadedPipelineExecutor(pipeline);
 
           // Initialize the transforms...
@@ -520,11 +595,15 @@ public class TransformBatchTransform extends TransformTransform {
 
           initCounter.inc();
 
+          pipeline.setLogLevel(LogLevel.NOTHING);
+
           // Doesn't really start the threads in single threaded mode
           // Just sets some flags all over the place
           //
           pipeline.startThreads();
 
+          pipeline.setLogLevel(LogLevel.BASIC);
+
           resultRows = new ArrayList<>();
 
           // Copy the info data sets to the info transforms...
@@ -661,7 +740,7 @@ public class TransformBatchTransform extends TransformTransform {
         }
 
         if (!rowBuffer.isEmpty()) {
-          System.err.println("Async action detected on rowBuffer");
+          LOG.error("Async action detected on rowBuffer");
         }
 
         // Empty all the row buffers for another iteration
@@ -762,39 +841,4 @@ public class TransformBatchTransform extends TransformTransform {
           "Configuration error, transform '" + transformName + "' not found in transformation");
     }
   }
-
-  private interface TupleOutputContext<T> {
-    void output(TupleTag<T> tupleTag, T output);
-  }
-
-  private class TransformProcessContext implements TupleOutputContext<HopRow> {
-
-    private DoFn.ProcessContext context;
-
-    public TransformProcessContext(DoFn.ProcessContext processContext) {
-      this.context = processContext;
-    }
-
-    @Override
-    public void output(TupleTag<HopRow> tupleTag, HopRow output) {
-      context.output(tupleTag, output);
-    }
-  }
-
-  private class TransformFinishBundleContext implements TupleOutputContext<HopRow> {
-
-    private DoFn.FinishBundleContext context;
-    private BoundedWindow batchWindow;
-
-    public TransformFinishBundleContext(
-        DoFn.FinishBundleContext context, BoundedWindow batchWindow) {
-      this.context = context;
-      this.batchWindow = batchWindow;
-    }
-
-    @Override
-    public void output(TupleTag<HopRow> tupleTag, HopRow output) {
-      context.output(tupleTag, output, Instant.now(), batchWindow);
-    }
-  }
 }
