@@ -43,6 +43,8 @@ import java.util.List;
 public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfiguration
     implements IBeamPipelineEngineRunConfiguration, IVariables, Cloneable {
 
+  public static final String EXPERIMENT_APACHE_HOP_PIPELINE = "apache_hop_pipeline";
+
   @GuiWidgetElement(
       order = "20000-dataflow-options",
       parentId = PipelineRunConfiguration.GUI_PLUGIN_ELEMENT_PARENT_ID,
@@ -355,6 +357,17 @@ public class BeamDataFlowPipelineRunConfiguration extends BeamPipelineRunConfigu
     //
     options.setUsePublicIps(isGcpUsingPublicIps());
 
+    // Flag this pipeline as being produced by Apache Hop
+    //
+    List<String> experiments = options.getExperiments();
+    if (experiments==null) {
+      experiments=new ArrayList<>();
+    } else {
+      experiments = new ArrayList<>(experiments);
+    }
+    experiments.add(EXPERIMENT_APACHE_HOP_PIPELINE);
+    options.setExperiments(experiments);
+
     if (StringUtils.isNotEmpty(getFatJar())) {
       options.setFilesToStage(Collections.singletonList(resolve(fatJar)));
     }
