@@ -17,6 +17,7 @@
 
 package org.apache.hop.beam.pipeline;
 
+import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.beam.runners.dataflow.DataflowRunner;
 import org.apache.beam.runners.direct.DirectRunner;
 import org.apache.beam.runners.flink.FlinkRunner;
@@ -31,6 +32,7 @@ import org.apache.commons.lang.StringUtils;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.coder.HopRowCoder;
 import org.apache.hop.beam.core.util.HopBeamUtil;
+import org.apache.hop.beam.engines.HopPipelineExecutionOptions;
 import org.apache.hop.beam.engines.IBeamPipelineEngineRunConfiguration;
 import org.apache.hop.beam.metadata.RunnerType;
 import org.apache.hop.beam.pipeline.handler.BeamGenericTransformHandler;
@@ -38,18 +40,23 @@ import org.apache.hop.beam.pipeline.handler.BeamGroupByTransformHandler;
 import org.apache.hop.beam.pipeline.handler.BeamMergeJoinTransformHandler;
 import org.apache.hop.beam.pipeline.handler.BeamRowGeneratorTransformHandler;
 import org.apache.hop.beam.util.BeamConst;
+import org.apache.hop.core.Const;
 import org.apache.hop.core.annotations.Transform;
 import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.extension.ExtensionPoint;
 import org.apache.hop.core.logging.ILogChannel;
 import org.apache.hop.core.logging.LogChannel;
+import org.apache.hop.core.logging.LogLevel;
 import org.apache.hop.core.metadata.SerializableMetadataProvider;
 import org.apache.hop.core.plugins.JarCache;
 import org.apache.hop.core.row.IRowMeta;
 import org.apache.hop.core.row.RowMeta;
 import org.apache.hop.core.variables.IVariables;
+import org.apache.hop.execution.sampler.IExecutionDataSampler;
+import org.apache.hop.execution.sampler.IExecutionDataSamplerStore;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.PipelineMeta;
+import org.apache.hop.pipeline.config.PipelineRunConfiguration;
 import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.groupby.GroupByMeta;
@@ -63,7 +70,10 @@ import org.jboss.jandex.IndexView;
 import java.io.File;
 import java.util.*;
 
-public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngineRunConfiguration> {
+public class HopPipelineMetaToBeamPipelineConverter {
+
+  protected final String runConfigName;
+  protected final PipelineRunConfiguration runConfiguration;
 
   protected IVariables variables;
   protected PipelineMeta pipelineMeta;
@@ -73,26 +83,41 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
   protected List<String> xpPluginClasses;
   protected Map<String, IBeamPipelineTransformHandler> transformHandlers;
   protected IBeamPipelineTransformHandler genericTransformHandler;
-  protected T pipelineRunConfiguration;
-
-  public HopPipelineMetaToBeamPipelineConverter() {
-    this.transformHandlers = new HashMap<>();
-    this.transformPluginClasses = new ArrayList<>();
-    this.xpPluginClasses = new ArrayList<>();
-  }
+  protected IBeamPipelineEngineRunConfiguration pipelineRunConfiguration;
+  protected final String dataSamplersJson;
+  protected final String parentLogChannelId;
 
   public HopPipelineMetaToBeamPipelineConverter(
       IVariables variables,
       PipelineMeta pipelineMeta,
       IHopMetadataProvider metadataProvider,
-      T pipelineRunConfiguration)
+      String runConfigName,
+      List<IExecutionDataSampler<? extends IExecutionDataSamplerStore>> dataSamplers,
+      String parentLogChannelId)
       throws HopException {
-    this();
+    this.transformPluginClasses = new ArrayList<>();
+    this.xpPluginClasses = new ArrayList<>();
+    this.transformHandlers = new HashMap<>();
+
+    // Serialize the data samplers to JSON
+    this.dataSamplersJson = serializeDataSamplers(dataSamplers);
+    this.parentLogChannelId = parentLogChannelId;
+
     this.variables = variables;
     this.pipelineMeta = pipelineMeta;
     this.metadataProvider = new SerializableMetadataProvider(metadataProvider);
     this.metaStoreJson = this.metadataProvider.toJson();
-    this.pipelineRunConfiguration = pipelineRunConfiguration;
+    this.runConfigName = runConfigName;
+
+    this.runConfiguration =
+        metadataProvider.getSerializer(PipelineRunConfiguration.class).load(runConfigName);
+
+    if (!(runConfiguration.getEngineRunConfiguration()
+        instanceof IBeamPipelineEngineRunConfiguration)) {
+      throw new HopException("You need to provide a Beam run configuration");
+    }
+    this.pipelineRunConfiguration =
+        (IBeamPipelineEngineRunConfiguration) runConfiguration.getEngineRunConfiguration();
 
     addClassesFromPluginsToStage(pipelineRunConfiguration.getPluginsToStage());
     this.transformPluginClasses.addAll(
@@ -102,6 +127,16 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
     addDefaultTransformHandlers();
   }
 
+  private String serializeDataSamplers(
+      List<IExecutionDataSampler<? extends IExecutionDataSamplerStore>> dataSamplers)
+      throws HopException {
+    try {
+      return new ObjectMapper().writeValueAsString(dataSamplers);
+    } catch (Exception e) {
+      throw new HopException("Error serializing data samplers to JSON", e);
+    }
+  }
+
   protected List<String> splitPluginClasses(String transformPluginClasses) {
     List<String> list = new ArrayList<>();
     if (StringUtils.isNotEmpty(transformPluginClasses)) {
@@ -196,6 +231,13 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
       pipelineOptions.setJobName(sanitizeJobName(pipelineMeta.getName()));
 
       pipelineOptions.setRunner(runnerClass);
+      pipelineOptions
+          .as(HopPipelineExecutionOptions.class)
+          .setLogLevel(
+              LogLevel.getLogLevelForCode(
+                      Const.NVL(pipelineRunConfiguration.getVariable(
+                      BeamConst.STRING_LOCAL_PIPELINE_FLAG_LOG_LEVEL), "MINIMAL")));
+
       Pipeline pipeline = Pipeline.create(pipelineOptions);
 
       pipeline.getCoderRegistry().registerCoderForClass(HopRow.class, new HopRowCoder());
@@ -206,7 +248,7 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
       //
       Map<String, PCollection<HopRow>> transformCollectionMap = new HashMap<>();
 
-      // Handle io
+      // Handle input
       //
       handleBeamInputTransforms(log, transformCollectionMap, pipeline);
 
@@ -288,7 +330,9 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
       transformHandler.handleTransform(
           log,
           variables,
+          runConfigName,
           pipelineRunConfiguration,
+          dataSamplersJson,
           metadataProvider,
           pipelineMeta,
           transformPluginClasses,
@@ -298,7 +342,8 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
           pipeline,
           pipelineMeta.getTransformFields(variables, transformMeta),
           null,
-          null);
+          null,
+          parentLogChannelId);
     }
   }
 
@@ -329,14 +374,31 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
       }
       TransformMeta previousTransform = previousTransforms.get(0);
 
-      PCollection<HopRow> input = transformCollectionMap.get(previousTransform.getName());
+      // See if this output transform isn't targeted specifically by the previous transform.
+      //
+      // Check in the map to see if previousTransform isn't targeting this one
+      //
+      String targetName =
+              HopBeamUtil.createTargetTupleId(
+                      previousTransform.getName(), transformMeta.getName());
+      PCollection<HopRow> input = transformCollectionMap.get(targetName);
       if (input == null) {
-        throw new HopException(
-            "Previous PCollection for transform "
-                + previousTransform.getName()
-                + " could not be found");
+        input = transformCollectionMap.get(previousTransform.getName());
+        if (input == null) {
+          throw new HopException(
+                  "Previous PCollection for transform "
+                          + previousTransform.getName()
+                          + " could not be found");
+        }
+      } else {
+        log.logBasic(
+                "Transform "
+                        + transformMeta.getName()
+                        + " reading from previous transform targeting this one using : "
+                        + targetName);
       }
 
+
       // What fields are we getting from the previous transform(s)?
       //
       IRowMeta rowMeta = pipelineMeta.getTransformFields(variables, previousTransform);
@@ -344,7 +406,9 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
       transformHandler.handleTransform(
           log,
           variables,
+          runConfigName,
           pipelineRunConfiguration,
+          dataSamplersJson,
           metadataProvider,
           pipelineMeta,
           transformPluginClasses,
@@ -354,7 +418,8 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
           pipeline,
           rowMeta,
           previousTransforms,
-          input);
+          input,
+          parentLogChannelId);
     }
   }
 
@@ -475,9 +540,7 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
 
             // Flatten all the collections.  It's business as usual behind this.
             //
-            input =
-                inputList.apply(
-                    transformMeta.getName() + " Flatten", Flatten.pCollections());
+            input = inputList.apply(transformMeta.getName() + " Flatten", Flatten.pCollections());
           }
         }
 
@@ -488,7 +551,9 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
         transformHandler.handleTransform(
             log,
             variables,
+            runConfigName,
             pipelineRunConfiguration,
+            dataSamplersJson,
             metadataProvider,
             pipelineMeta,
             transformPluginClasses,
@@ -498,7 +563,8 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
             pipeline,
             rowMeta,
             previousTransforms,
-            input);
+            input,
+            parentLogChannelId);
       }
     }
   }
@@ -508,19 +574,16 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
       throw new HopException(
           "Group By is not supported.  Use the Memory Group By transform instead.  It comes closest to Beam functionality.");
     }
-    if (meta instanceof SortRowsMeta) {
-      throw new HopException("Sort rows is not yet supported on Beam.");
-    }
+//    if (meta instanceof SortRowsMeta) {
+//      throw new HopException("Sort rows is not yet supported on Beam.");
+//    }
     if (meta instanceof UniqueRowsMeta) {
       throw new HopException(
           "The unique rows transform is not yet supported on Beam, for now use a Memory Group By to get distrinct rows");
     }
   }
 
-  /**
-   * Find the Beam Input transforms, return them
-   *
-   */
+  /** Find the Beam Input transforms, return them */
   private List<TransformMeta> findBeamInputs() {
     List<TransformMeta> transforms = new ArrayList<>();
     for (TransformMeta transformMeta : pipelineMeta.getPipelineHopTransforms(false)) {
@@ -710,7 +773,9 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
     return transformHandlers;
   }
 
-  /** @param transformHandlers The transformHandlers to set */
+  /**
+   * @param transformHandlers The transformHandlers to set
+   */
   public void setTransformHandlers(Map<String, IBeamPipelineTransformHandler> transformHandlers) {
     this.transformHandlers = transformHandlers;
   }
@@ -724,7 +789,9 @@ public class HopPipelineMetaToBeamPipelineConverter<T extends IBeamPipelineEngin
     return genericTransformHandler;
   }
 
-  /** @param genericTransformHandler The genericTransformHandler to set */
+  /**
+   * @param genericTransformHandler The genericTransformHandler to set
+   */
   public void setGenericTransformHandler(IBeamPipelineTransformHandler genericTransformHandler) {
     this.genericTransformHandler = genericTransformHandler;
   }
