@@ -21,7 +21,7 @@ import org.apache.beam.sdk.values.PCollection;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.transform.BeamInputTransform;
-import org.apache.hop.beam.core.util.JsonRowMeta;
+import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.beam.engines.IBeamPipelineEngineRunConfiguration;
 import org.apache.hop.beam.metadata.FileDefinition;
 import org.apache.hop.beam.pipeline.IBeamPipelineTransformHandler;
@@ -44,13 +44,14 @@ import java.util.Map;
 
 @Transform(
     id = "BeamInput",
-    name = "Beam Input",
-    description = "Describes a Beam Input",
+    name = "Beam File Input",
+    description = "Reads one or more file using the Beam execution framework",
     image = "beam-input.svg",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.BigData",
     keywords = "i18n::BeamInputMeta.keyword",
     documentationUrl = "/pipeline/transforms/beaminput.html")
-public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData> implements IBeamPipelineTransformHandler {
+public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData>
+    implements IBeamPipelineTransformHandler {
 
   @HopMetadataProperty(key = "input_location")
   private String inputLocation;
@@ -107,6 +108,13 @@ public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData> i
           "Unable to find file definition '" + fileDefinitionName + "' in the metadata");
     }
 
+    try {
+      fileDefinition.validate();
+    } catch (Exception e) {
+      throw new HopTransformException(
+          "There was an error validating file definition " + fileDefinition.getName(), e);
+    }
+
     return fileDefinition;
   }
 
@@ -124,7 +132,9 @@ public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData> i
   public void handleTransform(
       ILogChannel log,
       IVariables variables,
+      String runConfigurationName,
       IBeamPipelineEngineRunConfiguration runConfiguration,
+      String dataSamplersJson,
       IHopMetadataProvider metadataProvider,
       PipelineMeta pipelineMeta,
       List<String> transformPluginClasses,
@@ -134,7 +144,8 @@ public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData> i
       org.apache.beam.sdk.Pipeline pipeline,
       IRowMeta rowMeta,
       List<TransformMeta> previousTransforms,
-      PCollection<HopRow> input)
+      PCollection<HopRow> input,
+      String parentLogChannelId)
       throws HopException {
     // Input handling
     //
@@ -168,7 +179,9 @@ public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData> i
     return inputLocation;
   }
 
-  /** @param inputLocation The inputLocation to set */
+  /**
+   * @param inputLocation The inputLocation to set
+   */
   public void setInputLocation(String inputLocation) {
     this.inputLocation = inputLocation;
   }
@@ -182,7 +195,9 @@ public class BeamInputMeta extends BaseTransformMeta<BeamInput, BeamInputData> i
     return fileDefinitionName;
   }
 
-  /** @param fileDefinitionName The fileDescriptionName to set */
+  /**
+   * @param fileDefinitionName The fileDescriptionName to set
+   */
   public void setFileDefinitionName(String fileDefinitionName) {
     this.fileDefinitionName = fileDefinitionName;
   }
