@@ -21,7 +21,7 @@ import org.apache.beam.sdk.values.PCollection;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.transform.BeamOutputTransform;
-import org.apache.hop.beam.core.util.JsonRowMeta;
+import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.beam.engines.IBeamPipelineEngineRunConfiguration;
 import org.apache.hop.beam.metadata.FieldDefinition;
 import org.apache.hop.beam.metadata.FileDefinition;
@@ -46,8 +46,8 @@ import java.util.Map;
 @Transform(
     id = "BeamOutput",
     image = "beam-output.svg",
-    name = "Beam Output",
-    description = "Describes a Beam Output",
+    name = "Beam File Output",
+    description = "Performs a parallel write to a group of files using the Beam framework",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.BigData",
     keywords = "i18n::BeamOutputMeta.keyword",
     documentationUrl = "/pipeline/transforms/beamoutput.html")
@@ -104,7 +104,9 @@ public class BeamOutputMeta extends BaseTransformMeta<BeamOutput, BeamOutputData
   public void handleTransform(
       ILogChannel log,
       IVariables variables,
+      String runConfigurationName,
       IBeamPipelineEngineRunConfiguration runConfiguration,
+      String dataSamplersJson,
       IHopMetadataProvider metadataProvider,
       PipelineMeta pipelineMeta,
       List<String> transformPluginClasses,
@@ -114,7 +116,8 @@ public class BeamOutputMeta extends BaseTransformMeta<BeamOutput, BeamOutputData
       org.apache.beam.sdk.Pipeline pipeline,
       IRowMeta rowMeta,
       List<TransformMeta> previousTransforms,
-      PCollection<HopRow> input)
+      PCollection<HopRow> input,
+      String parentLogChannelId)
       throws HopException {
 
     FileDefinition outputFileDefinition;
