@@ -22,7 +22,7 @@ import org.apache.beam.sdk.values.PCollection;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hop.beam.core.HopRow;
 import org.apache.hop.beam.core.fn.TimestampFn;
-import org.apache.hop.beam.core.util.JsonRowMeta;
+import org.apache.hop.core.row.JsonRowMeta;
 import org.apache.hop.beam.engines.IBeamPipelineEngineRunConfiguration;
 import org.apache.hop.beam.pipeline.IBeamPipelineTransformHandler;
 import org.apache.hop.core.annotations.Transform;
@@ -99,7 +99,9 @@ public class BeamTimestampMeta extends BaseTransformMeta<Dummy, DummyData> imple
   public void handleTransform(
       ILogChannel log,
       IVariables variables,
+      String runConfigurationName,
       IBeamPipelineEngineRunConfiguration runConfiguration,
+      String dataSamplersJson,
       IHopMetadataProvider metadataProvider,
       PipelineMeta pipelineMeta,
       List<String> transformPluginClasses,
@@ -109,7 +111,8 @@ public class BeamTimestampMeta extends BaseTransformMeta<Dummy, DummyData> imple
       org.apache.beam.sdk.Pipeline pipeline,
       IRowMeta rowMeta,
       List<TransformMeta> previousTransforms,
-      PCollection<HopRow> input)
+      PCollection<HopRow> input,
+      String parentLogChannelId)
       throws HopException {
     if (!readingTimestamp && StringUtils.isNotEmpty(fieldName)) {
       if (rowMeta.searchValueMeta(fieldName) == null) {
