@@ -41,8 +41,10 @@ public class BeamDirectPipelineEngineTest extends BeamBasePipelineEngineTest {
         new PipelineRunConfiguration(
             "direct",
             "description",
+            "",
             Arrays.asList(new DescribedVariable("VAR1", "value1", "description1")),
-            configuration);
+            configuration,
+            null);
 
     metadataProvider.getSerializer(PipelineRunConfiguration.class).save(pipelineRunConfiguration);
 
