@@ -34,7 +34,6 @@ public class BeamSparkPipelineEngineTest extends BeamBasePipelineEngineTest {
 
   // Disabled because of log4j library dependency problems with Spark
   @Test
-  @Ignore
   public void testSparkPipelineEngine() throws Exception {
 
     BeamSparkPipelineRunConfiguration configuration = new BeamSparkPipelineRunConfiguration();
@@ -44,8 +43,10 @@ public class BeamSparkPipelineEngineTest extends BeamBasePipelineEngineTest {
         new PipelineRunConfiguration(
             "spark",
             "description",
+            "",
             Arrays.asList(new DescribedVariable("VAR1", "spark1", "description1")),
-            configuration);
+            configuration,
+            null);
 
     metadataProvider.getSerializer(PipelineRunConfiguration.class).save(pipelineRunConfiguration);
 
