@@ -33,7 +33,8 @@ import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineHopMeta;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.engine.IPipelineEngine;
-import org.apache.hop.pipeline.transform.*;
+import org.apache.hop.pipeline.transform.TransformMeta;
+import org.apache.hop.pipeline.transform.TransformMetaDataCombi;
 import org.neo4j.driver.Driver;
 import org.neo4j.driver.Session;
 import org.neo4j.driver.Transaction;
@@ -70,7 +71,7 @@ public class PipelineLoggingExtensionPoint
     //
     pipeline.getExtensionDataMap().put(PIPELINE_START_DATE, new Date());
 
-    String connectionName = pipeline.getVariable(Defaults.VARIABLE_NEO4J_LOGGING_CONNECTION);
+    String connectionName = pipeline.getVariable(Defaults.NEO4J_LOGGING_CONNECTION);
 
     try {
 
@@ -333,7 +334,7 @@ public class PipelineLoggingExtensionPoint
 
                 // Also log every transform copy
                 //
-                List<TransformMetaDataCombi<ITransform, ITransformMeta, ITransformData>> combis =
+                List<TransformMetaDataCombi> combis =
                     ((Pipeline) pipeline).getTransforms();
                 for (TransformMetaDataCombi combi : combis) {
                   String transformLogChannelId = combi.transform.getLogChannel().getLogChannelId();
