@@ -834,7 +834,7 @@ public class GraphModelEditor extends MetadataEditor<GraphModel> {
       if (transformName == null) {
         return;
       }
-      IRowMeta inputRowMeta = pipelineMeta.getTransformFields(getVariables(), transformName);
+      IRowMeta inputRowMeta = pipelineMeta.getTransformFields(manager.getVariables(), transformName);
 
       String[] fieldNames = inputRowMeta.getFieldNames();
 
@@ -2064,14 +2064,8 @@ public class GraphModelEditor extends MetadataEditor<GraphModel> {
     }
   }
 
-  @Override
-  public void setChanged() {
-    this.isChanged = true;
-    MetadataPerspective.getInstance().updateEditor(this);
-  }
-
   public void clearChanged() {
-    this.isChanged = false;
+    resetChanged();
     MetadataPerspective.getInstance().updateEditor(this);
   }
 }
