@@ -35,10 +35,7 @@ import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.neo4j.core.value.ValueMetaGraph;
 import org.apache.hop.neo4j.model.GraphPropertyType;
-import org.apache.hop.pipeline.Pipeline;
-import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.w3c.dom.Node;
 
@@ -57,7 +54,7 @@ import java.util.List;
 @InjectionSupported(
     localizationPrefix = "Cypher.Injection.",
     groups = {"PARAMETERS", "RETURNS"})
-public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cypher, CypherData> {
+public class CypherMeta extends BaseTransformMeta<Cypher, CypherData> {
 
   public static final String CONNECTION = "connection";
   public static final String CYPHER = "cypher";
@@ -140,21 +137,6 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     retryingOnDisconnect = true;
   }
 
-  @Override
-  public Cypher createTransform(
-      TransformMeta transformMeta,
-      CypherData iTransformData,
-      int i,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new Cypher(transformMeta, this, iTransformData, i, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public CypherData getTransformData() {
-    return new CypherData();
-  }
-
   @Override
   public String getDialogClassName() {
     return CypherDialog.class.getName();
@@ -299,7 +281,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return connectionName;
   }
 
-  /** @param connectionName The connectionName to set */
+  /**
+   * @param connectionName The connectionName to set
+   */
   public void setConnectionName(String connectionName) {
     this.connectionName = connectionName;
   }
@@ -313,7 +297,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return cypher;
   }
 
-  /** @param cypher The cypher to set */
+  /**
+   * @param cypher The cypher to set
+   */
   public void setCypher(String cypher) {
     this.cypher = cypher;
   }
@@ -327,7 +313,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return batchSize;
   }
 
-  /** @param batchSize The batchSize to set */
+  /**
+   * @param batchSize The batchSize to set
+   */
   public void setBatchSize(String batchSize) {
     this.batchSize = batchSize;
   }
@@ -341,7 +329,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return cypherFromField;
   }
 
-  /** @param cypherFromField The cypherFromField to set */
+  /**
+   * @param cypherFromField The cypherFromField to set
+   */
   public void setCypherFromField(boolean cypherFromField) {
     this.cypherFromField = cypherFromField;
   }
@@ -355,7 +345,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return readOnly;
   }
 
-  /** @param readOnly The readOnly to set */
+  /**
+   * @param readOnly The readOnly to set
+   */
   public void setReadOnly(boolean readOnly) {
     this.readOnly = readOnly;
   }
@@ -369,7 +361,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return retryingOnDisconnect;
   }
 
-  /** @param retryingOnDisconnect The retrying to set */
+  /**
+   * @param retryingOnDisconnect The retrying to set
+   */
   public void setRetryingOnDisconnect(boolean retryingOnDisconnect) {
     this.retryingOnDisconnect = retryingOnDisconnect;
   }
@@ -383,7 +377,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return cypherField;
   }
 
-  /** @param cypherField The cypherField to set */
+  /**
+   * @param cypherField The cypherField to set
+   */
   public void setCypherField(String cypherField) {
     this.cypherField = cypherField;
   }
@@ -397,7 +393,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return usingUnwind;
   }
 
-  /** @param usingUnwind The usingUnwind to set */
+  /**
+   * @param usingUnwind The usingUnwind to set
+   */
   public void setUsingUnwind(boolean usingUnwind) {
     this.usingUnwind = usingUnwind;
   }
@@ -420,12 +418,16 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return returningGraph;
   }
 
-  /** @param returningGraph The returningGraph to set */
+  /**
+   * @param returningGraph The returningGraph to set
+   */
   public void setReturningGraph(boolean returningGraph) {
     this.returningGraph = returningGraph;
   }
 
-  /** @param unwindMapName The unwindMapName to set */
+  /**
+   * @param unwindMapName The unwindMapName to set
+   */
   public void setUnwindMapName(String unwindMapName) {
     this.unwindMapName = unwindMapName;
   }
@@ -439,7 +441,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return parameterMappings;
   }
 
-  /** @param parameterMappings The parameterMappings to set */
+  /**
+   * @param parameterMappings The parameterMappings to set
+   */
   public void setParameterMappings(List<ParameterMapping> parameterMappings) {
     this.parameterMappings = parameterMappings;
   }
@@ -453,7 +457,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return returnValues;
   }
 
-  /** @param returnValues The returnValues to set */
+  /**
+   * @param returnValues The returnValues to set
+   */
   public void setReturnValues(List<ReturnValue> returnValues) {
     this.returnValues = returnValues;
   }
@@ -467,7 +473,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return returnGraphField;
   }
 
-  /** @param returnGraphField The returnGraphField to set */
+  /**
+   * @param returnGraphField The returnGraphField to set
+   */
   public void setReturnGraphField(String returnGraphField) {
     this.returnGraphField = returnGraphField;
   }
@@ -481,7 +489,9 @@ public class CypherMeta extends BaseTransformMeta implements ITransformMeta<Cyph
     return nrRetriesOnError;
   }
 
-  /** @param nrRetriesOnError The nrRetriesOnError to set */
+  /**
+   * @param nrRetriesOnError The nrRetriesOnError to set
+   */
   public void setNrRetriesOnError(String nrRetriesOnError) {
     this.nrRetriesOnError = nrRetriesOnError;
   }
