@@ -26,16 +26,8 @@ import org.apache.hop.core.row.IValueMeta;
 import org.apache.hop.core.row.RowDataUtil;
 import org.apache.hop.metadata.api.IHopMetadataSerializer;
 import org.apache.hop.neo4j.core.GraphUsage;
-import org.apache.hop.neo4j.core.data.GraphData;
-import org.apache.hop.neo4j.core.data.GraphNodeData;
-import org.apache.hop.neo4j.core.data.GraphPropertyData;
-import org.apache.hop.neo4j.core.data.GraphPropertyDataType;
-import org.apache.hop.neo4j.core.data.GraphRelationshipData;
-import org.apache.hop.neo4j.model.GraphModel;
-import org.apache.hop.neo4j.model.GraphNode;
-import org.apache.hop.neo4j.model.GraphProperty;
-import org.apache.hop.neo4j.model.GraphPropertyType;
-import org.apache.hop.neo4j.model.GraphRelationship;
+import org.apache.hop.neo4j.core.data.*;
+import org.apache.hop.neo4j.model.*;
 import org.apache.hop.neo4j.model.validation.ModelValidator;
 import org.apache.hop.neo4j.model.validation.NodeProperty;
 import org.apache.hop.neo4j.shared.NeoConnection;
@@ -43,25 +35,15 @@ import org.apache.hop.neo4j.shared.NeoConnectionUtils;
 import org.apache.hop.neo4j.transforms.BaseNeoTransform;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.neo4j.driver.Result;
 import org.neo4j.driver.summary.Notification;
 import org.neo4j.driver.summary.ResultSummary;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
+import java.util.*;
 import java.util.concurrent.atomic.AtomicInteger;
-import java.util.function.Function;
 
-public class GraphOutput extends BaseNeoTransform<GraphOutputMeta, GraphOutputData>
-    implements ITransform<GraphOutputMeta, GraphOutputData> {
+public class GraphOutput extends BaseNeoTransform<GraphOutputMeta, GraphOutputData> {
 
   public GraphOutput(
       TransformMeta transformMeta,
