@@ -39,11 +39,9 @@ import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
 import org.apache.hop.pipeline.DatabaseImpact;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
 import org.apache.hop.pipeline.transform.ITransformData;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.w3c.dom.Node;
 
@@ -66,8 +64,8 @@ import java.util.Objects;
     keywords = "i18n::CombinationLookupMeta.keyword",
     documentationUrl = "/pipeline/transforms/combinationlookup.html")
 @InjectionSupported(localizationPrefix = "CombinationLookup.Injection.")
-public class CombinationLookupMeta extends BaseTransformMeta
-    implements ITransformMeta<CombinationLookup, CombinationLookupData>, IProvidesModelerMeta {
+public class CombinationLookupMeta extends BaseTransformMeta<CombinationLookup, CombinationLookupData>
+  implements IProvidesModelerMeta {
 
   private static final Class<?> PKG = CombinationLookupMeta.class; // For Translator
 
@@ -908,21 +906,6 @@ public class CombinationLookupMeta extends BaseTransformMeta
     return retval;
   }
 
-  @Override
-  public CombinationLookup createTransform(
-      TransformMeta transformMeta,
-      CombinationLookupData data,
-      int cnr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new CombinationLookup(transformMeta, this, data, cnr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public CombinationLookupData getTransformData() {
-    return new CombinationLookupData();
-  }
-
   @Override
   public void analyseImpact(
       IVariables variables,
