@@ -25,13 +25,11 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 /** Check if a Credit Card is valid * */
 public class CreditCardValidator
-    extends BaseTransform<CreditCardValidatorMeta, CreditCardValidatorData>
-    implements ITransform<CreditCardValidatorMeta, CreditCardValidatorData> {
+    extends BaseTransform<CreditCardValidatorMeta, CreditCardValidatorData> {
 
   private static final Class<?> PKG = CreditCardValidatorMeta.class; // For Translator
 
