@@ -28,7 +28,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.io.DataInputStream;
@@ -36,8 +35,7 @@ import java.io.IOException;
 import java.net.SocketTimeoutException;
 import java.util.zip.GZIPInputStream;
 
-public class CubeInput extends BaseTransform<CubeInputMeta, CubeInputData>
-    implements ITransform<CubeInputMeta, CubeInputData> {
+public class CubeInput extends BaseTransform<CubeInputMeta, CubeInputData> {
 
   private static final Class<?> PKG = CubeInputMeta.class; // For Translator
 
