@@ -25,7 +25,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.io.DataOutputStream;
@@ -35,8 +34,7 @@ import java.util.zip.GZIPOutputStream;
 /**
  * Outputs a stream/series of rows to a file, effectively building a sort of (compressed) microcube.
  */
-public class CubeOutput extends BaseTransform<CubeOutputMeta, CubeOutputData>
-    implements ITransform<CubeOutputMeta, CubeOutputData> {
+public class CubeOutput extends BaseTransform<CubeOutputMeta, CubeOutputData> {
 
   private static final Class<?> PKG = CubeOutputMeta.class; // For Translator
 
