@@ -33,11 +33,17 @@ import java.io.InputStreamReader;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeoutException;
 
 /** Execute a process * */
 public class ExecProcess extends BaseTransform<ExecProcessMeta, ExecProcessData> {
 
   private static final Class<?> PKG = ExecProcessMeta.class; // For Translator
+  private boolean killing;
+  private CountDownLatch waitForLatch;
 
   public ExecProcess(
       TransformMeta transformMeta,
@@ -89,22 +95,19 @@ public class ExecProcess extends BaseTransform<ExecProcessMeta, ExecProcessData>
                   PKG, "ExecProcess.Exception.CouldnotFindField", meta.getProcessField()));
         }
       }
-      if (meta.isArgumentsInFields()) {
-        if (data.indexOfArguments == null) {
-          data.indexOfArguments = new int[meta.getArgumentFieldNames().length];
-          for (int i = 0; i < data.indexOfArguments.length; i++) {
-            String fieldName = meta.getArgumentFieldNames()[i];
-            data.indexOfArguments[i] = data.previousRowMeta.indexOfValue(fieldName);
-            if (data.indexOfArguments[i] < 0) {
-              logError(
-                  BaseMessages.getString(PKG, "ExecProcess.Exception.CouldnotFindField")
-                      + "["
-                      + fieldName
-                      + "]");
-              throw new HopException(
-                  BaseMessages.getString(
-                      PKG, "ExecProcess.Exception.CouldnotFindField", fieldName));
-            }
+      if (meta.isArgumentsInFields() && data.indexOfArguments == null) {
+        data.indexOfArguments = new int[meta.getArgumentFieldNames().length];
+        for (int i = 0; i < data.indexOfArguments.length; i++) {
+          String fieldName = meta.getArgumentFieldNames()[i];
+          data.indexOfArguments[i] = data.previousRowMeta.indexOfValue(fieldName);
+          if (data.indexOfArguments[i] < 0) {
+            logError(
+                BaseMessages.getString(PKG, "ExecProcess.Exception.CouldnotFindField")
+                    + "["
+                    + fieldName
+                    + "]");
+            throw new HopException(
+                BaseMessages.getString(PKG, "ExecProcess.Exception.CouldnotFindField", fieldName));
           }
         }
       }
@@ -141,14 +144,12 @@ public class ExecProcess extends BaseTransform<ExecProcessMeta, ExecProcessData>
         execProcess(processString, processResult);
       }
 
-      if (meta.isFailWhenNotSuccess()) {
-        if (processResult.getExistStatus() != 0) {
-          String errorString = processResult.getErrorStream();
-          if (Utils.isEmpty(errorString)) {
-            errorString = processResult.getOutputStream();
-          }
-          throw new HopException(errorString);
+      if (meta.isFailWhenNotSuccess() && processResult.getExistStatus() != 0) {
+        String errorString = processResult.getErrorStream();
+        if (Utils.isEmpty(errorString)) {
+          errorString = processResult.getOutputStream();
         }
+        throw new HopException(errorString);
       }
 
       // Add result field to input stream
@@ -197,6 +198,18 @@ public class ExecProcess extends BaseTransform<ExecProcessMeta, ExecProcessData>
     return true;
   }
 
+  @Override
+  public void stopRunning() throws HopException {
+    if (waitForLatch != null) {
+      killing = true;
+      try {
+        waitForLatch.await();
+      } catch (InterruptedException e) {
+        throw new HopException("Interrupted exception while kill the process", e);
+      }
+    }
+  }
+
   private void execProcess(String process, ProcessResult processresult) throws HopException {
     execProcess(new String[] {process}, processresult);
   }
@@ -204,6 +217,7 @@ public class ExecProcess extends BaseTransform<ExecProcessMeta, ExecProcessData>
   private void execProcess(String[] process, ProcessResult processresult) throws HopException {
 
     Process p = null;
+    waitForLatch = new CountDownLatch(1);
     try {
       String errorMsg = null;
       // execute process
@@ -219,16 +233,49 @@ public class ExecProcess extends BaseTransform<ExecProcessMeta, ExecProcessData>
       if (p == null) {
         processresult.setErrorStream(errorMsg);
       } else {
-        // get output stream
-        processresult.setOutputStream(
-            getOutputString(new BufferedReader(new InputStreamReader(p.getInputStream()))));
+        CompletableFuture<IOException> future =
+            p.onExit()
+                .thenApply(
+                    processRef -> {
+                      try {
+                        // get output stream
+                        processresult.setOutputStream(
+                            getOutputString(
+                                new BufferedReader(
+                                    new InputStreamReader(processRef.getInputStream()))));
 
-        // get error message
-        processresult.setErrorStream(
-            getOutputString(new BufferedReader(new InputStreamReader(p.getErrorStream()))));
+                        // get error message
+                        processresult.setErrorStream(
+                            getOutputString(
+                                new BufferedReader(
+                                    new InputStreamReader(processRef.getErrorStream()))));
+                      } catch (IOException e) {
+                        return e;
+                      }
+                      return null;
+                    });
 
         // Wait until end
-        p.waitFor();
+        IOException exception;
+        while (true) {
+          try {
+            exception = future.get(1, TimeUnit.SECONDS);
+            break;
+          } catch (TimeoutException ignore) {
+            if (killing) {
+              p.children().forEach(ProcessHandle::destroy);
+              if (p.isAlive()) {
+                p.destroy();
+              }
+              exception = future.get();
+              logMinimal(BaseMessages.getString(PKG, "ExecProcess.AbortProcess"));
+              break;
+            }
+          }
+        }
+        if (exception != null) {
+          throw exception;
+        }
 
         // get exit status
         processresult.setExistStatus(p.exitValue());
@@ -242,6 +289,10 @@ public class ExecProcess extends BaseTransform<ExecProcessMeta, ExecProcessData>
     } catch (Exception e) {
       throw new HopException(e);
     } finally {
+      if (killing || waitForLatch.getCount() > 0) {
+        waitForLatch.countDown();
+        killing = false;
+      }
       if (p != null) {
         p.destroy();
       }
