@@ -35,10 +35,8 @@ import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.resource.IResourceNaming;
 import org.apache.hop.resource.ResourceDefinition;
@@ -50,13 +48,12 @@ import java.util.Map;
 @Transform(
     id = "GetFilesRowsCount",
     image = "getfilesrowcount.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.GetFilesRowsCount",
-    description = "i18n::BaseTransform.TypeTooltipDesc.GetFilesRowsCount",
+    name = "i18n::GetFilesRowsCount.Name",
+    description = "i18n::GetFilesRowsCount.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Input",
     keywords = "i18n::GetFilesRowsCountMeta.keyword",
     documentationUrl = "/pipeline/transforms/getfilesrowcount.html")
-public class GetFilesRowsCountMeta extends BaseTransformMeta
-    implements ITransformMeta<GetFilesRowsCount, GetFilesRowsCountData> {
+public class GetFilesRowsCountMeta extends BaseTransformMeta<GetFilesRowsCount, GetFilesRowsCountData> {
   private static final Class<?> PKG = GetFilesRowsCountMeta.class; // For Translator
 
   public static final String[] RequiredFilesDesc =
@@ -533,21 +530,6 @@ public class GetFilesRowsCountMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public GetFilesRowsCount createTransform(
-      TransformMeta transformMeta,
-      GetFilesRowsCountData data,
-      int cnr,
-      PipelineMeta tr,
-      Pipeline pipeline) {
-    return new GetFilesRowsCount(transformMeta, this, data, cnr, tr, pipeline);
-  }
-
-  @Override
-  public GetFilesRowsCountData getTransformData() {
-    return new GetFilesRowsCountData();
-  }
-
   /**
    * Since the exported pipeline that runs this will reside in a ZIP file, we can't reference files
    * relatively. So what this does is turn the name of files into absolute paths OR it simply
