@@ -30,7 +30,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.http.*;
 import org.apache.http.client.AuthCache;
@@ -63,8 +62,7 @@ import java.util.List;
 import static org.apache.hop.pipeline.transforms.httppost.HttpPostMeta.DEFAULT_ENCODING;
 
 /** Make a HTTP Post call */
-public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData>
-    implements ITransform<HttpPostMeta, HttpPostData> {
+public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData> {
 
   private static final Class<?> PKG = HttpPostMeta.class; // For Translator
 
@@ -99,6 +97,9 @@ public class HttpPost extends BaseTransform<HttpPostMeta, HttpPostData>
     if (StringUtils.isNotBlank(data.realProxyHost)) {
       clientBuilder.setProxy(data.realProxyHost, data.realProxyPort);
     }
+    if (meta.isIgnoreSsl()) {
+      clientBuilder.ignoreSsl(true);
+    }
 
     CloseableHttpClient httpClient = clientBuilder.build();
 
