@@ -37,6 +37,7 @@ import org.json.simple.JSONObject;
 import java.io.BufferedOutputStream;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
+import java.util.Objects;
 
 /** Converts input rows to one or more Xml files. */
 public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
@@ -71,7 +72,7 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
     public void execute(Object[] row) throws HopException {
 
       for (int i = 0; i < data.nrFields; i++) {
-        JsonOutputField outputField = meta.getOutputFields()[i];
+        JsonOutputField outputField = meta.getOutputFields().get(i);
 
         IValueMeta v = data.inputRowMeta.getValueMeta(data.fieldIndexes[i]);
 
@@ -110,11 +111,9 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
 
       data.nrRow++;
 
-      if (data.nrRowsInBloc > 0) {
-        if (data.nrRow % data.nrRowsInBloc == 0) {
-          // We can now output an object
-          outPutRow(row);
-        }
+      if (data.nrRowsInBloc > 0 && data.nrRow % data.nrRowsInBloc == 0) {
+        // We can now output an object
+        outputRow(row);
       }
     }
   }
@@ -128,7 +127,7 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
       JSONObject jo = new JSONObject();
 
       for (int i = 0; i < data.nrFields; i++) {
-        JsonOutputField outputField = meta.getOutputFields()[i];
+        JsonOutputField outputField = meta.getOutputFields().get(i);
 
         IValueMeta v = data.inputRowMeta.getValueMeta(data.fieldIndexes[i]);
 
@@ -164,11 +163,9 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
 
       data.nrRow++;
 
-      if (data.nrRowsInBloc > 0) {
-        if (data.nrRow % data.nrRowsInBloc == 0) {
-          // We can now output an object
-          outPutRow(row);
-        }
+      if (data.nrRowsInBloc > 0 && data.nrRow % data.nrRowsInBloc == 0) {
+        // We can now output an object
+        outputRow(row);
       }
     }
   }
@@ -179,11 +176,7 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
   public boolean processRow() throws HopException {
     Object[] r = getRow(); // This also waits for a row to be finished.
     if (r == null) {
-      // no more input to be expected...
-      if (!data.rowsAreSafe) {
-        // Let's output the remaining unsafe data
-        outPutRow(r);
-      }
+      writeJsonToFile();
 
       setOutputDone();
       return false;
@@ -200,15 +193,15 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
 
       // Cache the field name indexes
       //
-      data.nrFields = meta.getOutputFields().length;
+      data.nrFields = meta.getOutputFields().size();
       data.fieldIndexes = new int[data.nrFields];
       for (int i = 0; i < data.nrFields; i++) {
         data.fieldIndexes[i] =
-            data.inputRowMeta.indexOfValue(meta.getOutputFields()[i].getFieldName());
+            data.inputRowMeta.indexOfValue(meta.getOutputFields().get(i).getFieldName());
         if (data.fieldIndexes[i] < 0) {
           throw new HopException(BaseMessages.getString(PKG, "JsonOutput.Exception.FieldNotFound"));
         }
-        JsonOutputField field = meta.getOutputFields()[i];
+        JsonOutputField field = meta.getOutputFields().get(i);
         field.setElementName(resolve(field.getElementName()));
       }
     }
@@ -223,14 +216,22 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
     return true;
   }
 
+  private void writeJsonToFile() throws HopTransformException {
+    // no more input to be expected...
+    if (!data.rowsAreSafe) {
+      // Let's output the remaining unsafe data
+      outputRow(null);
+    }
+  }
+
   @SuppressWarnings("unchecked")
-  private void outPutRow(Object[] rowData) throws HopTransformException {
+  private void outputRow(Object[] rowData) throws HopTransformException {
     // We can now output an object
     data.jg = new JSONObject();
     data.jg.put(data.realBlocName, data.ja);
     String value = data.jg.toJSONString();
 
-    if (data.outputValue && data.outputRowMeta != null) {
+    if (rowData != null && data.outputValue && data.outputRowMeta != null) {
       Object[] outputRowData = RowDataUtil.addValueData(rowData, data.inputRowMetaSize, value);
       incrementLinesOutput();
       putRow(data.outputRowMeta, outputRowData);
@@ -261,17 +262,17 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
 
     if (super.init()) {
 
-      data.writeToFile = (meta.getOperationType() != JsonOutputMeta.OPERATION_TYPE_OUTPUT_VALUE);
-      data.outputValue = (meta.getOperationType() != JsonOutputMeta.OPERATION_TYPE_WRITE_TO_FILE);
+      data.writeToFile =
+          (!Objects.equals(meta.getOperationType(), JsonOutputMeta.OPERATION_TYPE_OUTPUT_VALUE));
+      data.outputValue =
+          (!Objects.equals(meta.getOperationType(), JsonOutputMeta.OPERATION_TYPE_WRITE_TO_FILE));
 
-      if (data.outputValue) {
+      if (data.outputValue && Utils.isEmpty(resolve(meta.getOutputValue()))) {
         // We need to have output field name
-        if (Utils.isEmpty(resolve(meta.getOutputValue()))) {
-          logError(BaseMessages.getString(PKG, "JsonOutput.Error.MissingOutputFieldName"));
-          stopAll();
-          setErrors(1);
-          return false;
-        }
+        logError(BaseMessages.getString(PKG, "JsonOutput.Error.MissingOutputFieldName"));
+        stopAll();
+        setErrors(1);
+        return false;
       }
       if (data.writeToFile) {
         // We need to have output field name
@@ -281,13 +282,11 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
           setErrors(1);
           return false;
         }
-        if (!meta.isDoNotOpenNewFileInit()) {
-          if (!openNewFile()) {
-            logError(BaseMessages.getString(PKG, "JsonOutput.Error.OpenNewFile", buildFilename()));
-            stopAll();
-            setErrors(1);
-            return false;
-          }
+        if (!meta.isDoNotOpenNewFileInit() && !openNewFile()) {
+          logError(BaseMessages.getString(PKG, "JsonOutput.Error.OpenNewFile", buildFilename()));
+          stopAll();
+          setErrors(1);
+          return false;
         }
       }
       data.realBlocName = Const.NVL(resolve(meta.getJsonBloc()), "");
@@ -301,6 +300,15 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
   @Override
   public void dispose() {
     if (data.ja != null) {
+      // Is there some left-over data to be written to disk?
+      //
+      if (data.ja.size() > 0) {
+        try {
+          outputRow(null);
+        } catch (Exception e) {
+          log.logError("Error writing final rows to disk", e);
+        }
+      }
       data.ja = null;
     }
     if (data.jg != null) {
@@ -310,6 +318,25 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
     super.dispose();
   }
 
+  @Override
+  public void startBundle() throws HopException {
+    if (!first) {
+      openNewFile();
+    }
+  }
+
+  @Override
+  public void batchComplete() throws HopException {
+    if (!data.isBeamContext()) {
+      writeJsonToFile();
+    }
+  }
+
+  @Override
+  public void finishBundle() throws HopException {
+    writeJsonToFile();
+  }
+
   private void createParentFolder(String filename) throws HopTransformException {
     if (!meta.isCreateParentFolder()) {
       return;
@@ -355,7 +382,7 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
 
       String filename = buildFilename();
       createParentFolder(filename);
-      if (meta.addToResult()) {
+      if (meta.isAddToResult()) {
         // Add this to the result file names...
         ResultFile resultFile =
             new ResultFile(
@@ -395,7 +422,15 @@ public class JsonOutput extends BaseTransform<JsonOutputMeta, JsonOutputData> {
   }
 
   public String buildFilename() {
-    return meta.buildFilename(variables, getCopy() + "", null, data.splitnr + "", false);
+    return meta.buildFilename(
+        variables,
+        getCopy() + "",
+        null,
+        data.splitnr + "",
+        data.isBeamContext(),
+        log.getLogChannelId(),
+        data.getBeamBundleNr(),
+        false);
   }
 
   protected boolean closeFile() {
