@@ -33,7 +33,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 
 import java.io.BufferedInputStream;
@@ -44,8 +43,7 @@ import java.util.List;
 /**
  * Read files, parse them and convert them to rows and writes these to one or more output streams.
  */
-public class LoadFileInput extends BaseTransform<LoadFileInputMeta, LoadFileInputData>
-    implements ITransform<LoadFileInputMeta, LoadFileInputData> {
+public class LoadFileInput extends BaseTransform<LoadFileInputMeta, LoadFileInputData> {
 
   private static final Class<?> PKG = LoadFileInputMeta.class; // For Translator
 
