@@ -35,10 +35,8 @@ import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.resource.IResourceNaming;
 import org.apache.hop.resource.ResourceDefinition;
@@ -51,13 +49,12 @@ import java.util.Map;
 @Transform(
     id = "LoadFileInput",
     image = "loadfileinput.svg",
-    name = "i18n::BaseTransform.TypeLongDesc.LoadFileInput",
-    description = "i18n::BaseTransform.TypeTooltipDesc.LoadFileInput",
+    name = "i18n::LoadFileInput.Name",
+    description = "i18n::LoadFileInput.Description",
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Input",
     keywords = "i18n::LoadFileInputMeta.keyword",
     documentationUrl = "/pipeline/transforms/loadfileinput.html")
-public class LoadFileInputMeta extends BaseTransformMeta
-    implements ITransformMeta<LoadFileInput, LoadFileInputData> {
+public class LoadFileInputMeta extends BaseTransformMeta<LoadFileInput, LoadFileInputData> {
   private static final String INCLUDE = "include";
   private static final String INCLUDE_FIELD = "include_field";
   private static final String ROWNUM = "rownum";
@@ -837,21 +834,6 @@ public class LoadFileInputMeta extends BaseTransformMeta
     }
   }
 
-  @Override
-  public LoadFileInput createTransform(
-      TransformMeta transformMeta,
-      LoadFileInputData data,
-      int cnr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new LoadFileInput(transformMeta, this, data, cnr, pipelineMeta, pipeline);
-  }
-
-  @Override
-  public LoadFileInputData getTransformData() {
-    return new LoadFileInputData();
-  }
-
   @Override
   public boolean supportsErrorHandling() {
     return true;
