@@ -32,7 +32,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.ini4j.Wini;
 
@@ -46,8 +45,7 @@ import java.util.Properties;
  * Read all Properties files (& INI files) , convert them to rows and writes these to one or more
  * output streams.
  */
-public class PropertyInput extends BaseTransform<PropertyInputMeta, PropertyInputData>
-    implements ITransform<PropertyInputMeta, PropertyInputData> {
+public class PropertyInput extends BaseTransform<PropertyInputMeta, PropertyInputData> {
   private static final Class<?> PKG = PropertyInputMeta.class; // For Translator
 
   public PropertyInput(
