@@ -35,11 +35,8 @@ import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.core.xml.XmlHandler;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.metadata.api.IHopMetadataProvider;
-import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransformMeta;
-import org.apache.hop.pipeline.transform.ITransform;
-import org.apache.hop.pipeline.transform.ITransformMeta;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.resource.IResourceNaming;
 import org.apache.hop.resource.ResourceDefinition;
@@ -56,8 +53,7 @@ import java.util.Map;
     categoryDescription = "i18n:org.apache.hop.pipeline.transform:BaseTransform.Category.Input",
     keywords = "i18n::PropertyInputMeta.keyword",
     documentationUrl = "/pipeline/transforms/propertyinput.html")
-public class PropertyInputMeta extends BaseTransformMeta
-    implements ITransformMeta<PropertyInput, PropertyInputData> {
+public class PropertyInputMeta extends BaseTransformMeta<PropertyInput, PropertyInputData> {
   private static final Class<?> PKG = PropertyInputMeta.class; // For Translator
 
   public static final String[] RequiredFilesDesc =
@@ -539,16 +535,6 @@ public class PropertyInputMeta extends BaseTransformMeta
     return retval;
   }
 
-  @Override
-  public ITransform createTransform(
-      TransformMeta transformMeta,
-      PropertyInputData data,
-      int copyNr,
-      PipelineMeta pipelineMeta,
-      Pipeline pipeline) {
-    return new PropertyInput(transformMeta, this, data, copyNr, pipelineMeta, pipeline);
-  }
-
   @Override
   public String getXml() {
     StringBuilder retval = new StringBuilder(500);
@@ -968,12 +954,6 @@ public class PropertyInputMeta extends BaseTransformMeta
       remarks.add(cr);
     }
   }
-
-  @Override
-  public PropertyInputData getTransformData() {
-    return new PropertyInputData();
-  }
-
   @Override
   public boolean supportsErrorHandling() {
     return true;
