@@ -17,16 +17,6 @@
 
 package org.apache.hop.pipeline.transforms.rest;
 
-import com.sun.jersey.api.client.Client;
-import com.sun.jersey.api.client.ClientResponse;
-import com.sun.jersey.api.client.UniformInterfaceException;
-import com.sun.jersey.api.client.WebResource;
-import com.sun.jersey.api.client.filter.HTTPBasicAuthFilter;
-import com.sun.jersey.api.uri.UriComponent;
-import com.sun.jersey.client.apache4.config.ApacheHttpClient4Config;
-import com.sun.jersey.client.apache4.config.DefaultApacheHttpClient4Config;
-import com.sun.jersey.client.urlconnection.HTTPSProperties;
-import com.sun.jersey.core.util.MultivaluedMapImpl;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.encryption.Encr;
 import org.apache.hop.core.exception.HopException;
@@ -38,31 +28,25 @@ import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
-import org.apache.http.auth.AuthScope;
-import org.apache.http.auth.UsernamePasswordCredentials;
-import org.apache.http.client.CredentialsProvider;
-import org.apache.http.impl.client.BasicCredentialsProvider;
+import org.glassfish.jersey.apache.connector.ApacheConnectorProvider;
+import org.glassfish.jersey.client.ClientConfig;
+import org.glassfish.jersey.client.ClientProperties;
+import org.glassfish.jersey.client.HttpUrlConnectorProvider;
+import org.glassfish.jersey.client.authentication.HttpAuthenticationFeature;
+import org.glassfish.jersey.uri.UriComponent;
 import org.json.simple.JSONObject;
 
-import javax.net.ssl.HostnameVerifier;
 import javax.net.ssl.SSLContext;
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.MultivaluedMap;
-import javax.ws.rs.core.UriBuilder;
+import javax.ws.rs.client.*;
+import javax.ws.rs.core.*;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.lang.reflect.Field;
-import java.lang.reflect.Modifier;
-import java.net.HttpURLConnection;
 import java.security.KeyManagementException;
 import java.security.KeyStoreException;
 import java.security.NoSuchAlgorithmException;
 import java.security.cert.CertificateException;
-import java.util.Arrays;
-import java.util.LinkedHashSet;
 import java.util.List;
-import java.util.Set;
 
 public class Rest extends BaseTransform<RestMeta, RestData> {
   private static final Class<?> PKG = RestMeta.class; // For Translator
@@ -78,8 +62,8 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
   }
 
   /* for unit test*/
-  MultivaluedMapImpl createMultivalueMap(String paramName, String paramValue) {
-    MultivaluedMapImpl queryParams = new MultivaluedMapImpl();
+  MultivaluedHashMap createMultivalueMap(String paramName, String paramValue) {
+    MultivaluedHashMap queryParams = new MultivaluedHashMap();
     queryParams.add(paramName, UriComponent.encode(paramValue, UriComponent.Type.QUERY_PARAM));
     return queryParams;
   }
@@ -96,7 +80,7 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
         throw new HopException(BaseMessages.getString(PKG, "Rest.Error.MethodMissing"));
       }
     }
-    WebResource webResource = null;
+    WebTarget webResource = null;
     Client client = null;
     Object[] newRow = null;
     if (rowData != null) {
@@ -106,13 +90,20 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
       if (isDetailed()) {
         logDetailed(BaseMessages.getString(PKG, "Rest.Log.ConnectingToURL", data.realUrl));
       }
-      // create an instance of the com.sun.jersey.api.client.Client class
-      client = Client.create(data.config);
+      ClientBuilder clientBuilder = ClientBuilder.newBuilder();
+      clientBuilder
+          .withConfig(data.config)
+          .property(HttpUrlConnectorProvider.SET_METHOD_WORKAROUND, true);
+      if (meta.isIgnoreSsl() || !Utils.isEmpty(data.trustStoreFile)) {
+        clientBuilder.sslContext(data.sslContext);
+        clientBuilder.hostnameVerifier((s1, s2) -> true);
+      }
+      client = clientBuilder.build();
       if (data.basicAuthentication != null) {
-        client.addFilter(data.basicAuthentication);
+        client.register(data.basicAuthentication);
       }
       // create a WebResource object, which encapsulates a web resource for the client
-      webResource = client.resource(data.realUrl);
+      webResource = client.target(data.realUrl);
 
       // used for calculating the responseTime
       long startTime = System.currentTimeMillis();
@@ -132,7 +123,7 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
                   data.matrixParamNames[i],
                   UriComponent.encode(value, UriComponent.Type.QUERY_PARAM));
         }
-        webResource = client.resource(builder.build());
+        webResource = client.target(builder.build());
       }
 
       if (data.useParams) {
@@ -144,13 +135,13 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
                 BaseMessages.getString(
                     PKG, "Rest.Log.queryParameterValue", data.paramNames[i], value));
           }
-          webResource = webResource.queryParams(createMultivalueMap(data.paramNames[i], value));
+          webResource = webResource.queryParam(data.paramNames[i], value);
         }
       }
       if (isDebug()) {
-        logDebug(BaseMessages.getString(PKG, "Rest.Log.ConnectingToURL", webResource.getURI()));
+        logDebug(BaseMessages.getString(PKG, "Rest.Log.ConnectingToURL", webResource.getUri()));
       }
-      WebResource.Builder builder = webResource.getRequestBuilder();
+      Invocation.Builder invocationBuilder = webResource.request();
       String contentType = null; // media type override, if not null
       if (data.useHeaders) {
         // Add headers
@@ -158,7 +149,7 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
           String value = data.inputRowMeta.getString(rowData, data.indexOfHeaderFields[i]);
 
           // unsure if an already set header will be returned to builder
-          builder = builder.header(data.headerNames[i], value);
+          invocationBuilder.header(data.headerNames[i], value);
           if ("Content-Type".equals(data.headerNames[i])) {
             contentType = value;
           }
@@ -169,7 +160,7 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
         }
       }
 
-      ClientResponse response = null;
+      Response response = null;
       String entityString = null;
       if (data.useBody) {
         // Set Http request entity
@@ -180,45 +171,41 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
       }
       try {
         if (data.method.equals(RestMeta.HTTP_METHOD_GET)) {
-          response = builder.get(ClientResponse.class);
+          response = invocationBuilder.get(Response.class);
         } else if (data.method.equals(RestMeta.HTTP_METHOD_POST)) {
           if (null != contentType) {
-            response = builder.type(contentType).post(ClientResponse.class, entityString);
+            response = invocationBuilder.post(Entity.entity(entityString, contentType));
           } else {
-            response = builder.type(data.mediaType).post(ClientResponse.class, entityString);
+            response = invocationBuilder.post(Entity.entity(entityString, data.mediaType));
           }
         } else if (data.method.equals(RestMeta.HTTP_METHOD_PUT)) {
           if (null != contentType) {
-            response = builder.type(contentType).put(ClientResponse.class, entityString);
+            response = invocationBuilder.put(Entity.entity(entityString, contentType));
           } else {
-            response = builder.type(data.mediaType).put(ClientResponse.class, entityString);
+            response = invocationBuilder.put(Entity.entity(entityString, data.mediaType));
           }
         } else if (data.method.equals(RestMeta.HTTP_METHOD_DELETE)) {
-          response = builder.delete(ClientResponse.class);
+          response = invocationBuilder.delete();
         } else if (data.method.equals(RestMeta.HTTP_METHOD_HEAD)) {
-          response = builder.head();
+          response = invocationBuilder.head();
         } else if (data.method.equals(RestMeta.HTTP_METHOD_OPTIONS)) {
-          response = builder.options(ClientResponse.class);
+          response = invocationBuilder.options();
         } else if (data.method.equals(RestMeta.HTTP_METHOD_PATCH)) {
-          //Workaround to make PATCH work, remove when updating to Jersey 2.X
-          allowMethods("PATCH");
           if (null != contentType) {
             response =
-                builder
-                    .type(contentType)
-                    .method(RestMeta.HTTP_METHOD_PATCH, ClientResponse.class, entityString);
+                invocationBuilder.method(
+                    RestMeta.HTTP_METHOD_PATCH, Entity.entity(entityString, contentType));
           } else {
             response =
-                builder
-                    .type(data.mediaType)
-                    .method(RestMeta.HTTP_METHOD_PATCH, ClientResponse.class, entityString);
+                invocationBuilder.method(
+                    RestMeta.HTTP_METHOD_PATCH, Entity.entity(entityString, data.mediaType));
           }
         } else {
           throw new HopException(
               BaseMessages.getString(PKG, "Rest.Error.UnknownMethod", data.method));
         }
-      } catch (UniformInterfaceException u) {
-        response = u.getResponse();
+      } catch (Exception e) {
+        throw new HopException("Request could not be processed", e);
       }
       // Get response time
       long responseTime = System.currentTimeMillis() - startTime;
@@ -239,16 +226,16 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
       String body;
       String headerString = null;
       try {
-        body = response.getEntity(String.class);
-      } catch (UniformInterfaceException ex) {
+        body = response.readEntity(String.class);
+      } catch (Exception ex) {
         body = "";
       }
       // get Header
-      MultivaluedMap<String, String> headers = searchForHeaders(response);
+      MultivaluedMap<String, Object> headers = searchForHeaders(response);
       JSONObject json = new JSONObject();
-      for (java.util.Map.Entry<String, List<String>> entry : headers.entrySet()) {
+      for (java.util.Map.Entry<String, List<Object>> entry : headers.entrySet()) {
         String name = entry.getKey();
-        List<String> value = entry.getValue();
+        List<Object> value = entry.getValue();
         if (value.size() > 1) {
           json.put(name, value);
         } else {
@@ -287,7 +274,7 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
         webResource = null;
       }
       if (client != null) {
-        client.destroy();
+        client.close();
       }
     }
     return newRow;
@@ -296,36 +283,24 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
   private void setConfig() throws HopException {
     if (data.config == null) {
       // Use ApacheHttpClient for supporting proxy authentication.
-      data.config = new DefaultApacheHttpClient4Config();
+      data.config = new ClientConfig();
+      data.config.connectorProvider(new ApacheConnectorProvider());
       if (!Utils.isEmpty(data.realProxyHost)) {
         // PROXY CONFIGURATION
-        data.config
-            .getProperties()
-            .put(
-                ApacheHttpClient4Config.PROPERTY_PROXY_URI,
-                "http://" + data.realProxyHost + ":" + data.realProxyPort);
+        data.config.property(ClientProperties.PROXY_URI,"http://"+ data.realProxyHost + ":" + data.realProxyPort);
         if (!Utils.isEmpty(data.realHttpLogin) && !Utils.isEmpty(data.realHttpPassword)) {
-          AuthScope authScope = new AuthScope(data.realProxyHost, data.realProxyPort);
-          UsernamePasswordCredentials credentials =
-              new UsernamePasswordCredentials(data.realHttpLogin, data.realHttpPassword);
-          CredentialsProvider credentialsProvider = new BasicCredentialsProvider();
-          credentialsProvider.setCredentials(authScope, credentials);
-          data.config
-              .getProperties()
-              .put(ApacheHttpClient4Config.PROPERTY_CREDENTIALS_PROVIDER, credentialsProvider);
+          data.config.property(ClientProperties.PROXY_USERNAME, data.realHttpLogin);
+          data.config.property(ClientProperties.PROXY_PASSWORD, data.realHttpPassword);
         }
       } else {
         if (!Utils.isEmpty(data.realHttpLogin)) {
           // Basic authentication
           data.basicAuthentication =
-              new HTTPBasicAuthFilter(data.realHttpLogin, data.realHttpPassword);
+              HttpAuthenticationFeature.basicBuilder()
+                  .credentials(data.realHttpLogin, data.realHttpPassword)
+                  .build();
         }
       }
-      if (meta.isPreemptive()) {
-        data.config
-            .getProperties()
-            .put(ApacheHttpClient4Config.PROPERTY_PREEMPTIVE_BASIC_AUTHENTICATION, true);
-      }
       // SSL TRUST STORE CONFIGURATION
       if (!Utils.isEmpty(data.trustStoreFile) && !meta.isIgnoreSsl()) {
         setTrustStoreFile();
@@ -339,11 +314,8 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
   private void setTrustAll() throws HopException {
     try {
       SSLContext ctx = HttpClientManager.getTrustAllSslContext();
-      HostnameVerifier hv = HttpClientManager.getHostnameVerifier(isDebug(), log);
 
-      data.config
-          .getProperties()
-          .put(HTTPSProperties.PROPERTY_HTTPS_PROPERTIES, new HTTPSProperties(hv, ctx));
+      data.sslContext = ctx;
     } catch (NoSuchAlgorithmException e) {
       throw new HopException(BaseMessages.getString(PKG, "Rest.Error.NoSuchAlgorithm"), e);
     } catch (KeyManagementException e) {
@@ -357,11 +329,8 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
       SSLContext ctx =
           HttpClientManager.getSslContextWithTrustStoreFile(
               trustFileStream, data.trustStorePassword);
-      HostnameVerifier hv = HttpClientManager.getHostnameVerifier(isDebug(), log);
 
-      data.config
-          .getProperties()
-          .put(HTTPSProperties.PROPERTY_HTTPS_PROPERTIES, new HTTPSProperties(hv, ctx));
+      data.sslContext = ctx;
     } catch (NoSuchAlgorithmException e) {
       throw new HopException(BaseMessages.getString(PKG, "Rest.Error.NoSuchAlgorithm"), e);
     } catch (KeyStoreException e) {
@@ -378,7 +347,7 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
     }
   }
 
-  protected MultivaluedMap<String, String> searchForHeaders(ClientResponse response) {
+  protected MultivaluedMap<String, Object> searchForHeaders(Response response) {
     return response.getHeaders();
   }
 
@@ -604,26 +573,4 @@ public class Rest extends BaseTransform<RestMeta, RestData> {
     data.paramNames = null;
     super.dispose();
   }
-
-  // Workaround to make PATCH method work, remove when updating to jersey 2.X
-  private static void allowMethods(String... methods) {
-    try {
-      Field methodsField = HttpURLConnection.class.getDeclaredField("methods");
-
-      Field modifiersField = Field.class.getDeclaredField("modifiers");
-      modifiersField.setAccessible(true);
-      modifiersField.setInt(methodsField, methodsField.getModifiers() & ~Modifier.FINAL);
-
-      methodsField.setAccessible(true);
-
-      String[] oldMethods = (String[]) methodsField.get(null);
-      Set<String> methodsSet = new LinkedHashSet<>(Arrays.asList(oldMethods));
-      methodsSet.addAll(Arrays.asList(methods));
-      String[] newMethods = methodsSet.toArray(new String[0]);
-
-      methodsField.set(null /*static field*/, newMethods);
-    } catch (NoSuchFieldException | IllegalAccessException e) {
-      throw new IllegalStateException(e);
-    }
-  }
 }
