@@ -37,7 +37,6 @@ import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.Pipeline;
 import org.apache.hop.pipeline.PipelineMeta;
 import org.apache.hop.pipeline.transform.BaseTransform;
-import org.apache.hop.pipeline.transform.ITransform;
 import org.apache.hop.pipeline.transform.TransformMeta;
 import org.apache.hop.pipeline.transforms.fileinput.TextFileInput;
 import org.apache.hop.pipeline.transforms.fileinput.TextFileInputMeta;
@@ -50,8 +49,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 /** Read a simple CSV file Just output Strings found in the file... */
-public class CsvInput extends BaseTransform<CsvInputMeta, CsvInputData>
-    implements ITransform<CsvInputMeta, CsvInputData> {
+public class CsvInput extends BaseTransform<CsvInputMeta, CsvInputData> {
 
   private static final Class<?> PKG = CsvInput.class; // For Translator
 
