@@ -299,18 +299,6 @@ public class AddXmlDialog extends BaseTransformDialog implements ITransformDialo
 
     final int FieldsRows = input.getOutputFields().length;
 
-    // Prepare a list of possible formats...
-    String[] dats = Const.getDateFormats();
-    String[] nums = Const.getNumberFormats();
-    int totsize = dats.length + nums.length;
-    String[] formats = new String[totsize];
-    for (int x = 0; x < dats.length; x++) {
-      formats[x] = dats[x];
-    }
-    for (int x = 0; x < nums.length; x++) {
-      formats[dats.length + x] = nums[x];
-    }
-
     colinf =
         new ColumnInfo[] {
           new ColumnInfo(
@@ -328,8 +316,8 @@ public class AddXmlDialog extends BaseTransformDialog implements ITransformDialo
               ValueMetaBase.getTypes()),
           new ColumnInfo(
               BaseMessages.getString(PKG, "AddXMLDialog.Format.Column"),
-              ColumnInfo.COLUMN_TYPE_CCOMBO,
-              formats),
+              ColumnInfo.COLUMN_TYPE_FORMAT,
+              3),
           new ColumnInfo(
               BaseMessages.getString(PKG, "AddXMLDialog.Length.Column"),
               ColumnInfo.COLUMN_TYPE_TEXT,
