@@ -27,9 +27,9 @@ import org.apache.hop.core.util.Utils;
 import org.apache.hop.history.AuditManager;
 import org.apache.hop.history.AuditState;
 import org.apache.hop.ui.core.gui.GuiResource;
-import org.apache.hop.ui.core.gui.HopNamespace;
 import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.core.widget.OsHelper;
+import org.apache.hop.ui.hopgui.HopGui;
 import org.apache.hop.ui.hopgui.TextSizeUtilFacade;
 import org.apache.hop.ui.util.EnvironmentUtils;
 import org.eclipse.swt.SWT;
@@ -365,7 +365,7 @@ public class PropsUi extends Props {
   public void setScreen(WindowProperty windowProperty) {
     AuditManager.storeState(
         LogChannel.UI,
-        HopNamespace.getNamespace(),
+        HopGui.DEFAULT_HOP_GUI_NAMESPACE,
         "shells",
         windowProperty.getName(),
         windowProperty.getStateProperties());
@@ -377,7 +377,7 @@ public class PropsUi extends Props {
     }
     AuditState auditState =
         AuditManager.retrieveState(
-            LogChannel.UI, HopNamespace.getNamespace(), "shells", windowName);
+            LogChannel.UI, HopGui.DEFAULT_HOP_GUI_NAMESPACE, "shells", windowName);
     if (auditState == null) {
       return null;
     }
@@ -483,7 +483,7 @@ public class PropsUi extends Props {
           control.addPaintListener(
               paintEvent -> {
                 paintEvent.gc.setForeground(gui.getColorBlack());
-                paintEvent.gc.setBackground(gui.getColorBackground());
+                paintEvent.gc.setBackground(gui.getColorWhite());
                 paintEvent.gc.fillRectangle(
                     2, 0, control.getBounds().width - 8, control.getBounds().height - 20);
               });
@@ -501,9 +501,13 @@ public class PropsUi extends Props {
         font = gui.getFontFixed();
         break;
       case WIDGET_STYLE_TABLE:
-        foreground = gui.getColorBlack();
-        background = gui.getColorWhite();
-        font = null;
+        background = gui.getColorLightGray();
+        foreground = gui.getColorDarkGray();
+        if (control instanceof Table) {
+          Table table = (Table) control;
+          table.setHeaderBackground(gui.getColorLightGray());
+          table.setHeaderForeground(gui.getColorDarkGray());
+        }
         break;
       case WIDGET_STYLE_NOTEPAD:
         foreground = gui.getColorBlack();
@@ -524,14 +528,12 @@ public class PropsUi extends Props {
         }
         break;
       case WIDGET_STYLE_TAB:
-        background = gui.getColorWhite();
-        foreground = gui.getColorBlack();
         CTabFolder tabFolder = (CTabFolder) control;
         tabFolder.setBorderVisible(true);
-        // need to make a copy of the tab selection background color to get around bug
-        Color c = gui.getColorTab();
-        Color tabColor = new Color(c.getDevice(), c.getRed(), c.getGreen(), c.getBlue());
-        tabFolder.setSelectionBackground(tabColor);
+        tabFolder.setBackground(gui.getColorGray());
+        tabFolder.setForeground(gui.getColorBlack());
+        tabFolder.setSelectionBackground(gui.getColorWhite());
+        tabFolder.setSelectionForeground(gui.getColorBlack());
         break;
       default:
         background = gui.getColorBackground();
@@ -762,10 +764,13 @@ public class PropsUi extends Props {
     contrastingColors.put(toRGB("#c9e8fb"), toRGB("#0f88d2"));
 
     contrastingColors.put(new RGB(254, 254, 254), new RGB(35, 35, 35));
-    contrastingColors.put(new RGB(240, 240, 240), new RGB(15, 15, 15));
-    contrastingColors.put(new RGB(225, 225, 225), new RGB(30, 30, 30));
-    contrastingColors.put(new RGB(215, 215, 215), new RGB(40, 40, 40));
-    contrastingColors.put(new RGB(100, 100, 100), new RGB(155, 155, 155));
+    contrastingColors.put(new RGB(245, 245, 245), new RGB(40, 40, 40));
+    contrastingColors.put(new RGB(240, 240, 240), new RGB(45, 45, 45));
+    contrastingColors.put(new RGB(235, 235, 235), new RGB(50, 50, 50));
+    contrastingColors.put(new RGB(225, 225, 225), new RGB(70, 70, 70));
+    contrastingColors.put(new RGB(215, 215, 215), new RGB(100, 100, 100));
+    contrastingColors.put(new RGB(100, 100, 100), new RGB(215, 215, 215));
+    contrastingColors.put(new RGB(50, 50, 50), new RGB(235, 235, 235));
 
     // Add all the inverse color mappings as well
     //
