@@ -55,61 +55,63 @@ public class GuiResource {
   // 33 resources
 
   /* * * Colors * * */
-  private ManagedColor colorBackground;
+  private Color colorBackground;
 
-  private ManagedColor colorGraph;
+  private Color colorGraph;
 
-  private ManagedColor colorTab;
+  private Color colorTab;
 
-  private ManagedColor colorRed;
+  private Color colorRed;
 
-  private ManagedColor colorSuccessGreen;
+  private Color colorSuccessGreen;
 
-  private ManagedColor colorBlueCustomGrid;
+  private Color colorBlueCustomGrid;
 
-  private ManagedColor colorGreen;
+  private Color colorGreen;
 
-  private ManagedColor colorBlue;
+  private Color colorBlue;
 
-  private ManagedColor colorOrange;
+  private Color colorOrange;
 
-  private ManagedColor colorYellow;
+  private Color colorYellow;
 
-  private ManagedColor colorMagenta;
+  private Color colorMagenta;
 
-  private ManagedColor colorPurpule;
+  private Color colorPurpule;
 
-  private ManagedColor colorIndigo;
+  private Color colorIndigo;
 
-  private ManagedColor colorBlack;
+  private Color colorBlack;
 
-  private ManagedColor colorGray;
+  private Color colorGray;
 
-  private ManagedColor colorDarkGray;
+  private Color colorDarkGray;
 
-  private ManagedColor colorLightGray;
+  private Color colorVeryDarkGray;
 
-  private ManagedColor colorDemoGray;
+  private Color colorLightGray;
 
-  private ManagedColor colorWhite;
+  private Color colorDemoGray;
 
-  private ManagedColor colorDirectory;
+  private Color colorWhite;
 
-  private ManagedColor colorHop;
+  private Color colorDirectory;
 
-  private ManagedColor colorLight;
+  private Color colorHop;
 
-  private ManagedColor colorCream;
+  private Color colorLight;
 
-  private ManagedColor colorLightBlue;
+  private Color colorCream;
 
-  private ManagedColor colorCrystalText;
+  private Color colorLightBlue;
 
-  private ManagedColor colorHopDefault;
+  private Color colorCrystalText;
 
-  private ManagedColor colorHopTrue;
+  private Color colorHopDefault;
 
-  private ManagedColor colorDeprecated;
+  private Color colorHopTrue;
+
+  private Color colorDeprecated;
 
   /* * * Fonts * * */
   private ManagedFont fontGraph;
@@ -246,6 +248,7 @@ public class GuiResource {
   private Image imageNew;
   private Image imageDown;
   private Image imageUp;
+  private Image imageLocation;
 
   private Map<String, Image> imageMap;
 
@@ -335,42 +338,37 @@ public class GuiResource {
     imageMap = new HashMap<>();
     colorMap = new HashMap<>();
 
-    colorBackground = new ManagedColor(display, props.contrastColor(new RGB(240,240,240)));
-    colorGraph = new ManagedColor(display, props.contrastColor(new RGB(255,255,255)));
-    colorTab = new ManagedColor(display, props.contrastColor(new RGB(128,128,128)));
-    colorSuccessGreen = new ManagedColor(display, props.contrastColor(0, 139, 0));
-    colorRed = new ManagedColor(display, props.contrastColor(255, 0, 0));
-    colorGreen = new ManagedColor(display, props.contrastColor(0, 255, 0));
-    colorBlue = new ManagedColor(display, props.contrastColor(0, 0, 255));
-    colorYellow = new ManagedColor(display, props.contrastColor(255, 255, 0));
-    colorMagenta = new ManagedColor(display, props.contrastColor(255, 0, 255));
-    colorPurpule = new ManagedColor(display, props.contrastColor(128, 0, 128));
-    colorIndigo = new ManagedColor(display, props.contrastColor(75, 0, 130));
-    colorOrange = new ManagedColor(display, props.contrastColor(255, 165, 0));
-
-    colorBlueCustomGrid = new ManagedColor(display, props.contrastColor(240, 248, 255));
-
-    colorWhite = new ManagedColor(display, props.contrastColor(254, 254, 254));
-    colorDemoGray = new ManagedColor(display, props.contrastColor(240, 240, 240));
-    colorLightGray = new ManagedColor(display, props.contrastColor(225, 225, 225));
-    colorGray = new ManagedColor(display, props.contrastColor(215, 215, 215));
-    colorDarkGray = new ManagedColor(display, props.contrastColor(100, 100, 100));
-    colorBlack = new ManagedColor(display, props.contrastColor(0, 0, 0));
-    colorLightBlue =
-        new ManagedColor(display, props.contrastColor(135, 206, 250)); // light sky blue
-
-    colorDirectory = new ManagedColor(display, props.contrastColor(0, 0, 255));
-    colorHop = new ManagedColor(display, props.contrastColor(188, 198, 82));
-    colorLight = new ManagedColor(display, props.contrastColor(238, 248, 152));
-    colorCream = new ManagedColor(display, props.contrastColor(248, 246, 231));
-
-    colorCrystalText = new ManagedColor(display, props.contrastColor(61, 99, 128));
-
-    colorHopDefault = new ManagedColor(display, props.contrastColor(61, 99, 128));
-
-    colorHopTrue = new ManagedColor(display, props.contrastColor(12, 178, 15));
-
-    colorDeprecated = new ManagedColor(display, props.contrastColor(246, 196, 56));
+    // It is recommended not to use the Device to create the color, but the RAP needs a screen (to
+    // be removed if the RAP evolves)!
+    colorBackground = new Color(display, props.contrastColor(new RGB(240, 240, 240)));
+    colorGraph = new Color(display, props.contrastColor(new RGB(235, 235, 235)));
+    colorTab = new Color(display, props.contrastColor(new RGB(128, 128, 128)));
+    colorSuccessGreen = new Color(display, props.contrastColor(0, 139, 0));
+    colorRed = new Color(display, props.contrastColor(255, 0, 0));
+    colorGreen = new Color(display, props.contrastColor(0, 255, 0));
+    colorBlue = new Color(display, props.contrastColor(0, 0, 255));
+    colorYellow = new Color(display, props.contrastColor(255, 255, 0));
+    colorMagenta = new Color(display, props.contrastColor(255, 0, 255));
+    colorPurpule = new Color(display, props.contrastColor(128, 0, 128));
+    colorIndigo = new Color(display, props.contrastColor(75, 0, 130));
+    colorOrange = new Color(display, props.contrastColor(255, 165, 0));
+    colorBlueCustomGrid = new Color(display, props.contrastColor(240, 248, 255));
+    colorWhite = new Color(display, props.contrastColor(254, 254, 254));
+    colorDemoGray = new Color(display, props.contrastColor(240, 240, 240));
+    colorLightGray = new Color(display, props.contrastColor(225, 225, 225));
+    colorGray = new Color(display, props.contrastColor(215, 215, 215));
+    colorDarkGray = new Color(display, props.contrastColor(100, 100, 100));
+    colorVeryDarkGray = new Color(display, props.contrastColor(50, 50, 50));
+    colorBlack = new Color(display, props.contrastColor(0, 0, 0));
+    colorLightBlue = new Color(display, props.contrastColor(135, 206, 250)); // light sky blue
+    colorDirectory = new Color(display, props.contrastColor(0, 0, 255));
+    colorHop = new Color(display, props.contrastColor(188, 198, 82));
+    colorLight = new Color(display, props.contrastColor(238, 248, 152));
+    colorCream = new Color(display, props.contrastColor(248, 246, 231));
+    colorCrystalText = new Color(display, props.contrastColor(61, 99, 128));
+    colorHopDefault = new Color(display, props.contrastColor(61, 99, 128));
+    colorHopTrue = new Color(display, props.contrastColor(12, 178, 15));
+    colorDeprecated = new Color(display, props.contrastColor(246, 196, 56));
 
     // Load all images from files...
     loadFonts();
@@ -381,36 +379,6 @@ public class GuiResource {
   }
 
   private void dispose(boolean reload) {
-    // Colors
-    colorBackground.dispose();
-    colorGraph.dispose();
-    colorTab.dispose();
-
-    colorRed.dispose();
-    colorSuccessGreen.dispose();
-    colorGreen.dispose();
-    colorBlue.dispose();
-    colorGray.dispose();
-    colorYellow.dispose();
-    colorMagenta.dispose();
-    colorPurpule.dispose();
-    colorIndigo.dispose();
-    colorOrange.dispose();
-    colorBlueCustomGrid.dispose();
-
-    colorWhite.dispose();
-    colorDemoGray.dispose();
-    colorLightGray.dispose();
-    colorDarkGray.dispose();
-    colorBlack.dispose();
-    colorLightBlue.dispose();
-
-    colorDirectory.dispose();
-    colorHop.dispose();
-    colorLight.dispose();
-    colorCream.dispose();
-
-    disposeColors(colorMap.values());
 
     if (!reload) {
       // display shutdown, clean up our mess
@@ -513,6 +481,7 @@ public class GuiResource {
       imageSearch.dispose();
       imageDown.dispose();
       imageUp.dispose();
+      imageLocation.dispose();
 
       imageArrowDefault.dispose();
       imageArrowTrue.dispose();
@@ -561,12 +530,6 @@ public class GuiResource {
     }
   }
 
-  private void disposeColors(Collection<Color> colors) {
-    for (Color color : colors) {
-      color.dispose();
-    }
-  }
-
   private void disposeImage(Image image) {
     if (image != null && !image.isDisposed()) {
       image.dispose();
@@ -759,6 +722,7 @@ public class GuiResource {
     imageView = loadAsResource(display, "ui/images/view.svg", ConstUi.SMALL_ICON_SIZE);
     imageDown = loadAsResource(display, "ui/images/down.svg", ConstUi.SMALL_ICON_SIZE);
     imageUp = loadAsResource(display, "ui/images/up.svg", ConstUi.SMALL_ICON_SIZE);
+    imageLocation = loadAsResource(display, "ui/images/location.svg", ConstUi.SMALL_ICON_SIZE);
 
     // Svg image
     //
@@ -920,147 +884,208 @@ public class GuiResource {
     }
   }
 
-  /** @return Returns the colorBackground. */
+  /**
+   * @return Returns the colorBackground.
+   */
   public Color getColorBackground() {
-    return colorBackground.getColor();
+    return colorBackground;
   }
 
-  /** @return Returns the colorBlack. */
+  /**
+   * @return Returns the colorBlack.
+   */
   public Color getColorBlack() {
-    return colorBlack.getColor();
+    return colorBlack;
   }
 
-  /** @return Returns the colorBlue. */
+  /**
+   * @return Returns the colorBlue.
+   */
   public Color getColorBlue() {
-    return colorBlue.getColor();
+    return colorBlue;
   }
 
-  /** @return Returns the colorDarkGray. */
+  /**
+   * @return Returns the colorDarkGray.
+   */
   public Color getColorDarkGray() {
-    return colorDarkGray.getColor();
+    return colorDarkGray;
   }
 
-  /** @return Returns the colorDemoGray. */
+  /**
+   * @return Returns veryDarkGray.
+   */
+  public Color getColorVeryDarkGray() {
+    return colorVeryDarkGray;
+  }
+
+  /**
+   * @return Returns the colorDemoGray.
+   */
   public Color getColorDemoGray() {
-    return colorDemoGray.getColor();
+    return colorDemoGray;
   }
 
-  /** @return Returns the colorDirectory. */
+  /**
+   * @return Returns the colorDirectory.
+   */
   public Color getColorDirectory() {
-    return colorDirectory.getColor();
+    return colorDirectory;
   }
 
-  /** @return Returns the colorGraph. */
+  /**
+   * @return Returns the colorGraph.
+   */
   public Color getColorGraph() {
-    return colorGraph.getColor();
+    return colorGraph;
   }
 
-  /** @return Returns the colorGray. */
+  /**
+   * @return Returns the colorGray.
+   */
   public Color getColorGray() {
-    return colorGray.getColor();
+    return colorGray;
   }
 
-  /** @return Returns the colorGreen. */
+  /**
+   * @return Returns the colorGreen.
+   */
   public Color getColorGreen() {
-    return colorGreen.getColor();
+    return colorGreen;
   }
 
-  /** @return Returns the colorLightGray. */
+  /**
+   * @return Returns the colorLightGray.
+   */
   public Color getColorLightGray() {
-    return colorLightGray.getColor();
+    return colorLightGray;
   }
 
-  /** @return Returns the colorLightBlue. */
+  /**
+   * @return Returns the colorLightBlue.
+   */
   public Color getColorLightBlue() {
-    return colorLightBlue.getColor();
+    return colorLightBlue;
   }
 
-  /** @return Returns the colorMagenta. */
+  /**
+   * @return Returns the colorMagenta.
+   */
   public Color getColorMagenta() {
-    return colorMagenta.getColor();
+    return colorMagenta;
   }
 
   public Color getColorPurpule() {
-    return colorPurpule.getColor();
+    return colorPurpule;
   }
 
   public Color getColorIndigo() {
-    return colorIndigo.getColor();
+    return colorIndigo;
   }
 
-  /** @return Returns the colorOrange. */
+  /**
+   * @return Returns the colorOrange.
+   */
   public Color getColorOrange() {
-    return colorOrange.getColor();
+    return colorOrange;
   }
 
-  /** @return Returns the colorSuccessGreen. */
+  /**
+   * @return Returns the colorSuccessGreen.
+   */
   public Color getColorSuccessGreen() {
-    return colorSuccessGreen.getColor();
+    return colorSuccessGreen;
   }
 
-  /** @return Returns the colorRed. */
+  /**
+   * @return Returns the colorRed.
+   */
   public Color getColorRed() {
-    return colorRed.getColor();
+    return colorRed;
   }
 
-  /** @return Returns the colorBlueCustomGrid. */
+  /**
+   * @return Returns the colorBlueCustomGrid.
+   */
   public Color getColorBlueCustomGrid() {
-    return colorBlueCustomGrid.getColor();
+    return colorBlueCustomGrid;
   }
 
-  /** @return Returns the colorTab. */
+  /**
+   * @return Returns the colorTab.
+   */
   public Color getColorTab() {
-    return colorTab.getColor();
+    return colorTab;
   }
 
-  /** @return Returns the colorWhite. */
+  /**
+   * @return Returns the colorWhite.
+   */
   public Color getColorWhite() {
-    return colorWhite.getColor();
+    return colorWhite;
   }
 
-  /** @return Returns the colorYellow. */
+  /**
+   * @return Returns the colorYellow.
+   */
   public Color getColorYellow() {
-    return colorYellow.getColor();
+    return colorYellow;
   }
 
-  /** @return Returns the fontFixed. */
+  /**
+   * @return Returns the fontFixed.
+   */
   public Font getFontFixed() {
     return fontFixed.getFont();
   }
 
-  /** @return Returns the fontGraph. */
+  /**
+   * @return Returns the fontGraph.
+   */
   public Font getFontGraph() {
     return fontGraph.getFont();
   }
 
-  /** @return Returns the fontNote. */
+  /**
+   * @return Returns the fontNote.
+   */
   public Font getFontNote() {
     return fontNote.getFont();
   }
 
-  /** @return Returns the imageBol. */
+  /**
+   * @return Returns the imageBol.
+   */
   public Image getImageBol() {
     return imageBol.getAsBitmapForSize(display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return Returns the imageCalendar. */
+  /**
+   * @return Returns the imageCalendar.
+   */
   public Image getImageCalendar() {
     return imageCalendar;
   }
 
-  /** @return Returns the imageServer. */
+  /**
+   * @return Returns the imageServer.
+   */
   public Image getImageServer() {
     return imageServer.getAsBitmapForSize(
         display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return Returns the database image. */
+  /**
+   * @return Returns the database image.
+   */
   public Image getImageDatabase() {
     return imageDatabase.getAsBitmapForSize(
         display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return Returns the data image. */
+  /**
+   * @return Returns the data image.
+   */
   public Image getImageData() {
     return imageData.getAsBitmapForSize(display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
@@ -1077,38 +1102,52 @@ public class GuiResource {
     return imageAdd;
   }
 
-  /** @return Returns the table image. */
+  /**
+   * @return Returns the table image.
+   */
   public Image getImageTable() {
     return imageTable;
   }
 
-  /** @return Returns the preview image. */
+  /**
+   * @return Returns the preview image.
+   */
   public Image getImagePreview() {
     return imagePreview.getAsBitmapForSize(
         display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return Returns the imageSchema. */
+  /**
+   * @return Returns the imageSchema.
+   */
   public Image getImageSchema() {
     return imageSchema;
   }
 
-  /** @return Returns the imageSynonym. */
+  /**
+   * @return Returns the imageSynonym.
+   */
   public Image getImageSynonym() {
     return imageSynonym;
   }
 
-  /** @return Returns the imageView. */
+  /**
+   * @return Returns the imageView.
+   */
   public Image getImageNote() {
     return imageNote;
   }
 
-  /** @return Returns the imageColor. */
+  /**
+   * @return Returns the imageColor.
+   */
   public Image getImageColor() {
     return imageColor;
   }
 
-  /** @return Returns the imageMissing. */
+  /**
+   * @return Returns the imageMissing.
+   */
   public Image getImageMissing() {
     return imageMissing.getAsBitmapForSize(display, ConstUi.ICON_SIZE, ConstUi.ICON_SIZE);
   }
@@ -1117,23 +1156,31 @@ public class GuiResource {
     return imageMissing;
   }
 
-  /** @return Returns the imageHop. */
+  /**
+   * @return Returns the imageHop.
+   */
   public Image getImageHop() {
     return imageLogo.getAsBitmapForSize(display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return Returns the imageDisabledHop. */
+  /**
+   * @return Returns the imageDisabledHop.
+   */
   public Image getImageDisabledHop() {
     return imageDisabledHop.getAsBitmapForSize(
         display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return Returns the imagesTransforms. */
+  /**
+   * @return Returns the imagesTransforms.
+   */
   public Map<String, SwtUniversalImage> getImagesTransforms() {
     return imagesTransforms;
   }
 
-  /** @return Returns the imagesActions. */
+  /**
+   * @return Returns the imagesActions.
+   */
   public Map<String, SwtUniversalImage> getImagesActions() {
     return imagesActions;
   }
@@ -1148,22 +1195,30 @@ public class GuiResource {
     return imagesValueMeta.get(String.valueOf(valueMeta.getType()));
   }
 
-  /** @return the fontLarge */
+  /**
+   * @return the fontLarge
+   */
   public Font getFontLarge() {
     return fontLarge.getFont();
   }
 
-  /** @return the tiny font */
+  /**
+   * @return the tiny font
+   */
   public Font getFontTiny() {
     return fontTiny.getFont();
   }
 
-  /** @return the small font */
+  /**
+   * @return the small font
+   */
   public Font getFontSmall() {
     return fontSmall.getFont();
   }
 
-  /** @return Returns the clipboard. */
+  /**
+   * @return Returns the clipboard.
+   */
   public Clipboard getNewClipboard() {
     if (clipboard != null) {
       clipboard.dispose();
@@ -1201,7 +1256,9 @@ public class GuiResource {
         device, (int) (zoomFactor * width), (int) (zoomFactor * height));
   }
 
-  /** @return the imageVariable */
+  /**
+   * @return the imageVariable
+   */
   public Image getImageVariable() {
     return getZoomedImaged(imageVariable, display, 10, 10);
   }
@@ -1238,7 +1295,9 @@ public class GuiResource {
     return imageResetOption;
   }
 
-  /** @return the imageArrow */
+  /**
+   * @return the imageArrow
+   */
   public Image getImageArrow() {
     return getZoomedImaged(imageArrow, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
@@ -1247,27 +1306,37 @@ public class GuiResource {
     return imageArrow;
   }
 
-  /** @return the imageArrow */
+  /**
+   * @return the imageArrow
+   */
   public Image getImageFolder() {
     return getZoomedImaged(imageFolder, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return the imageFile */
+  /**
+   * @return the imageFile
+   */
   public Image getImageFile() {
     return getZoomedImaged(imageFile, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return the color */
+  /**
+   * @return the color
+   */
   public Color getColorHop() {
-    return colorHop.getColor();
+    return colorHop;
   }
 
-  /** @return the imageLogoSmall */
+  /**
+   * @return the imageLogoSmall
+   */
   public Image getImageHopUi() {
     return getZoomedImaged(imageLogo, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
 
-  /** @return the image size for Taskbar */
+  /**
+   * @return the image size for Taskbar
+   */
   public Image getImageHopUiTaskbar() {
     if (OsHelper.isMac()) {
       return getZoomedImaged(imageLogo, display, 512, 512);
@@ -1276,34 +1345,46 @@ public class GuiResource {
     }
   }
 
-  /** @return the colorLight */
+  /**
+   * @return the colorLight
+   */
   public Color getColorLight() {
-    return colorLight.getColor();
+    return colorLight;
   }
 
-  /** @return the colorCream */
+  /**
+   * @return the colorCream
+   */
   public Color getColorCream() {
-    return colorCream.getColor();
+    return colorCream;
   }
 
-  /** @return the default color of text in the Crystal theme */
+  /**
+   * @return the default color of text in the Crystal theme
+   */
   public Color getColorCrystalText() {
-    return colorCrystalText.getColor();
+    return colorCrystalText;
   }
 
-  /** @return the default color the hop lines for default/unconditional */
+  /**
+   * @return the default color the hop lines for default/unconditional
+   */
   public Color getColorHopDefault() {
-    return colorHopDefault.getColor();
+    return colorHopDefault;
   }
 
-  /** @return the default color the hop lines for the "OK" condition */
+  /**
+   * @return the default color the hop lines for the "OK" condition
+   */
   public Color getColorHopTrue() {
-    return colorHopTrue.getColor();
+    return colorHopTrue;
   }
 
-  /** @return the default color the deprecated condition */
+  /**
+   * @return the default color the deprecated condition
+   */
   public Color getColorDeprecated() {
-    return colorDeprecated.getColor();
+    return colorDeprecated;
   }
 
   public void drawGradient(Display display, GC gc, Rectangle rect, boolean vertical) {
@@ -1335,72 +1416,100 @@ public class GuiResource {
     return p;
   }
 
-  /** @return the fontMedium */
+  /**
+   * @return the fontMedium
+   */
   public Font getFontMedium() {
     return fontMedium.getFont();
   }
 
-  /** @return the fontMediumBold */
+  /**
+   * @return the fontMediumBold
+   */
   public Font getFontMediumBold() {
     return fontMediumBold.getFont();
   }
 
-  /** @return the imageShowLog */
+  /**
+   * @return the imageShowLog
+   */
   public Image getImageShowLog() {
     return imageShowLog;
   }
 
-  /** @return the imageShowGrid */
+  /**
+   * @return the imageShowGrid
+   */
   public Image getImageShowGrid() {
     return imageShowGrid;
   }
 
-  /** @return the imageShowHistory */
+  /**
+   * @return the imageShowHistory
+   */
   public Image getImageShowHistory() {
     return imageShowHistory;
   }
 
-  /** @return the imageShowPerf */
+  /**
+   * @return the imageShowPerf
+   */
   public Image getImageShowPerf() {
     return imageShowPerf;
   }
 
-  /** @return the "hide" image */
+  /**
+   * @return the "hide" image
+   */
   public Image getImageHide() {
     return imageHide;
   }
 
-  /** @return the "show" image */
+  /**
+   * @return the "show" image
+   */
   public Image getImageShow() {
     return imageShow;
   }
 
-  /** @return the "show selected" image */
+  /**
+   * @return the "show selected" image
+   */
   public Image getImageShowSelected() {
     return imageShowSelected;
   }
 
-  /** @return the "show all" image */
+  /**
+   * @return the "show all" image
+   */
   public Image getImageShowAll() {
     return imageShowAll;
   }
 
-  /** @return the close panel image */
+  /**
+   * @return the close panel image
+   */
   public Image getImageClosePanel() {
     return imageClosePanel;
   }
 
-  /** @return the maximize panel image */
+  /**
+   * @return the maximize panel image
+   */
   public Image getImageMaximizePanel() {
     return imageMaximizePanel;
   }
 
-  /** @return the minimize panel image */
+  /**
+   * @return the minimize panel image
+   */
   public Image getImageMinimizePanel() {
     return imageMinimizePanel;
   }
 
-  /** @return the show error lines image */
+  /**
+   * @return the show error lines image
+   */
   public Image getImageShowErrorLines() {
     return imageShowErrorLines;
   }
@@ -1686,7 +1795,9 @@ public class GuiResource {
     return imageMap;
   }
 
-  /** @return the imageTrue */
+  /**
+   * @return the imageTrue
+   */
   public Image getImageTrue() {
     return getZoomedImaged(imageTrue, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
@@ -1699,7 +1810,9 @@ public class GuiResource {
     return imageTrueDisabled;
   }
 
-  /** @return the imageFalse */
+  /**
+   * @return the imageFalse
+   */
   public Image getImageFalse() {
     return getZoomedImaged(imageFalse, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
   }
@@ -1728,7 +1841,9 @@ public class GuiResource {
     return imageSuccess;
   }
 
-  /** @return the imageContextMenu */
+  /**
+   * @return the imageContextMenu
+   */
   public Image getImageContextMenu() {
     return getZoomedImaged(
         imageContextMenu, display, ConstUi.SMALL_ICON_SIZE, ConstUi.SMALL_ICON_SIZE);
@@ -1809,6 +1924,10 @@ public class GuiResource {
     return imageUp;
   }
 
+  public Image getImageLocation() {
+    return imageLocation;
+  }
+
   public Image getImageAddAll() {
     return imageAddAll;
   }
