@@ -20,6 +20,7 @@ package org.apache.hop.ui.hopgui.perspective.dataorch;
 import org.apache.hop.core.Const;
 import org.apache.hop.core.Props;
 import org.apache.hop.core.exception.HopException;
+import org.apache.hop.core.exception.HopFileException;
 import org.apache.hop.core.extension.ExtensionPointHandler;
 import org.apache.hop.core.extension.HopExtensionPoint;
 import org.apache.hop.core.gui.plugin.GuiPlugin;
@@ -27,8 +28,10 @@ import org.apache.hop.core.gui.plugin.key.GuiKeyboardShortcut;
 import org.apache.hop.core.gui.plugin.key.GuiOsxKeyboardShortcut;
 import org.apache.hop.core.search.ISearchable;
 import org.apache.hop.core.search.ISearchableCallback;
+import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.pipeline.PipelineMeta;
+import org.apache.hop.pipeline.engine.IPipelineEngine;
 import org.apache.hop.ui.core.PropsUi;
 import org.apache.hop.ui.core.gui.GuiResource;
 import org.apache.hop.ui.core.widget.TabFolderReorder;
@@ -47,6 +50,7 @@ import org.apache.hop.ui.hopgui.perspective.HopPerspectivePlugin;
 import org.apache.hop.ui.hopgui.perspective.IHopPerspective;
 import org.apache.hop.ui.hopgui.perspective.TabItemHandler;
 import org.apache.hop.workflow.WorkflowMeta;
+import org.apache.hop.workflow.engine.IWorkflowEngine;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CTabFolder;
 import org.eclipse.swt.custom.CTabFolder2Adapter;
@@ -264,6 +268,17 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
     IHopFileTypeHandler typeHandler = tabItemHandler.getTypeHandler();
     boolean isRemoved = remove(typeHandler);
 
+    //
+    // Remove the file in refreshDelegate
+    try {
+      if (isRemoved && typeHandler.getFilename() != null) {
+        hopGui.fileRefreshDelegate.remove(
+            HopVfs.getFileObject(typeHandler.getFilename()).getPublicURIString());
+      }
+    } catch (HopFileException e) {
+      hopGui.getLog().logError("Error getting VFS fileObject", e);
+    }
+
     // Ignore event if canceled
     if (!isRemoved) {
       event.doit = false;
@@ -370,6 +385,12 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
         new HopGuiPipelineGraph(tabFolder, hopGui, tabItem, this, pipelineMeta, pipelineFile);
     tabItem.setControl(pipelineGraph);
 
+    // If it's a new pipeline, the file name will be null. So, ignore
+    //
+    if (pipelineMeta.getFilename() != null) {
+      hopGui.fileRefreshDelegate.register(
+          HopVfs.getFileObject(pipelineMeta.getFilename()).getPublicURIString(), pipelineGraph);
+    }
     // Set the tab name
     //
     updateTabLabel(tabItem, pipelineMeta.getFilename(), pipelineMeta.getName());
@@ -439,6 +460,13 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
         new HopGuiWorkflowGraph(tabFolder, hopGui, tabItem, this, workflowMeta, workflowFile);
     tabItem.setControl(workflowGraph);
 
+    // If it's a new workflow, the file name will be null
+    //
+    if (workflowMeta.getFilename() != null) {
+      hopGui.fileRefreshDelegate.register(
+          HopVfs.getFileObject(workflowMeta.getFilename()).getPublicURIString(), workflowGraph);
+    }
+
     // Update the internal variables (file specific) in the workflow graph variables
     //
     workflowMeta.setInternalHopVariables(workflowGraph.getVariables());
@@ -692,6 +720,40 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
     return searchables;
   }
 
+  public TabItemHandler findPipeline(String logChannelId) {
+    // Go over all the pipeline graphs and see if there's one that has a IPipelineEngine with the given ID
+    //
+    for (TabItemHandler item : items) {
+      if (item.getTypeHandler() instanceof HopGuiPipelineGraph) {
+        HopGuiPipelineGraph graph = (HopGuiPipelineGraph) item.getTypeHandler();
+        IPipelineEngine<PipelineMeta> pipeline = graph.getPipeline();
+        if (pipeline!=null) {
+          if (logChannelId.equals(pipeline.getLogChannelId())) {
+            return item;
+          }
+        }
+      }
+    }
+    return null;
+  }
+
+  public TabItemHandler findWorkflow(String logChannelId) {
+    // Go over all the workflow graphs and see if there's one that has a IWorkflow with the given ID
+    //
+    for (TabItemHandler item : items) {
+      if (item.getTypeHandler() instanceof HopGuiWorkflowGraph) {
+        HopGuiWorkflowGraph graph = (HopGuiWorkflowGraph) item.getTypeHandler();
+        IWorkflowEngine<WorkflowMeta> workflow = graph.getWorkflow();
+        if (workflow!=null) {
+          if (logChannelId.equals(workflow.getLogChannelId())) {
+            return item;
+          }
+        }
+      }
+    }
+    return null;
+  }
+
   /**
    * Gets items
    *
@@ -702,7 +764,9 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
     return items;
   }
 
-  /** @param items The items to set */
+  /**
+   * @param items The items to set
+   */
   public void setItems(List<TabItemHandler> items) {
     this.items = items;
   }
@@ -716,7 +780,9 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
     return activeItem;
   }
 
-  /** @param activeItem The activeItem to set */
+  /**
+   * @param activeItem The activeItem to set
+   */
   public void setActiveItem(TabItemHandler activeItem) {
     this.activeItem = activeItem;
   }
@@ -730,7 +796,9 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
     return hopGui;
   }
 
-  /** @param hopGui The hopGui to set */
+  /**
+   * @param hopGui The hopGui to set
+   */
   public void setHopGui(HopGui hopGui) {
     this.hopGui = hopGui;
   }
@@ -749,7 +817,9 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
     return tabFolder;
   }
 
-  /** @param tabFolder The tabFolder to set */
+  /**
+   * @param tabFolder The tabFolder to set
+   */
   public void setTabFolder(CTabFolder tabFolder) {
     this.tabFolder = tabFolder;
   }
@@ -771,4 +841,5 @@ public class HopDataOrchestrationPerspective implements IHopPerspective {
   public HopWorkflowFileType<WorkflowMeta> getWorkflowFileType() {
     return workflowFileType;
   }
+
 }
