@@ -23,6 +23,7 @@ import org.apache.hop.core.Const;
 import org.apache.hop.core.Props;
 import org.apache.hop.core.SwtUniversalImageSvg;
 import org.apache.hop.core.exception.HopException;
+import org.apache.hop.core.exception.HopFileException;
 import org.apache.hop.core.extension.ExtensionPointHandler;
 import org.apache.hop.core.gui.plugin.GuiPlugin;
 import org.apache.hop.core.gui.plugin.GuiRegistry;
@@ -40,6 +41,7 @@ import org.apache.hop.core.svg.SvgImage;
 import org.apache.hop.core.vfs.HopVfs;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.PropsUi;
+import org.apache.hop.ui.core.bus.HopGuiEvents;
 import org.apache.hop.ui.core.dialog.EnterStringDialog;
 import org.apache.hop.ui.core.dialog.ErrorDialog;
 import org.apache.hop.ui.core.gui.GuiResource;
@@ -241,6 +243,22 @@ public class ExplorerPerspective implements IHopPerspective {
 
     sash.setWeights(20, 80);
 
+    // refresh the file explorer when project activated or updated.
+    //
+    hopGui
+        .getEventsHandler()
+        .addEventListener(
+            getClass().getName() + "ProjectActivated",
+            e -> refresh(),
+            HopGuiEvents.ProjectActivated.name());
+
+    hopGui
+        .getEventsHandler()
+        .addEventListener(
+            getClass().getName() + "ProjectUpdated",
+            e -> refresh(),
+            HopGuiEvents.ProjectUpdated.name());
+
     HopGuiKeyHandler.getInstance().addParentObjectToHandle(this);
   }
 
@@ -585,14 +603,12 @@ public class ExplorerPerspective implements IHopPerspective {
     }
   }
 
-  public void addFile(ExplorerFile explorerFile, IExplorerFileTypeHandler renderer) {
+  public void addFile(ExplorerFile explorerFile) {
 
     if (files.contains(explorerFile)) {
       return;
     }
 
-    PropsUi props = PropsUi.getInstance();
-
     // Create tab item
     //
     CTabItem tabItem = new CTabItem(tabFolder, SWT.CLOSE);
@@ -621,6 +637,7 @@ public class ExplorerPerspective implements IHopPerspective {
           }
         });
 
+    PropsUi props = PropsUi.getInstance();
     // Create composite for editor and buttons
     //
     Composite composite = new Composite(tabFolder, SWT.NONE);
@@ -630,6 +647,7 @@ public class ExplorerPerspective implements IHopPerspective {
     composite.setLayout(layoutComposite);
     props.setLook(composite);
 
+    IExplorerFileTypeHandler renderer = explorerFile.getFileTypeHandler();
     // This is usually done by the file type
     //
     renderer.renderFile(composite);
@@ -654,6 +672,7 @@ public class ExplorerPerspective implements IHopPerspective {
     tabItem.setData(explorerFile);
 
     files.add(explorerFile);
+    hopGui.fileRefreshDelegate.register(explorerFile.getFilename(), renderer);
 
     // Activate perspective
     //
@@ -670,6 +689,10 @@ public class ExplorerPerspective implements IHopPerspective {
     updateGui();
   }
 
+  public void refreshFileContent() {
+    tabFolder.getChildren();
+  }
+
   private void selectInTree(String filename) {
     // Look in the whole tree for the file...
     //
@@ -769,6 +792,15 @@ public class ExplorerPerspective implements IHopPerspective {
       files.remove(file);
       tabItem.dispose();
 
+      //
+      // Remove the file in refreshDelegate
+      try {
+        hopGui.fileRefreshDelegate.remove(
+            HopVfs.getFileObject(file.getFileTypeHandler().getFilename()).getPublicURIString());
+      } catch (HopFileException e) {
+        hopGui.getLog().logError("Error getting VFS fileObject", e);
+      }
+
       // Refresh tree to remove bold
       //
       this.refresh();
@@ -884,7 +916,7 @@ public class ExplorerPerspective implements IHopPerspective {
       toolTip = "i18n::ExplorerPerspective.ToolbarElement.Refresh.Tooltip",
       image = "ui/images/refresh.svg")
   @GuiKeyboardShortcut(key = SWT.F5)
-  @GuiOsxKeyboardShortcut(key = SWT.F5)  
+  @GuiOsxKeyboardShortcut(key = SWT.F5)
   public void refresh() {
     try {
       determineRootFolderName(hopGui);
