@@ -471,22 +471,17 @@ public class MetadataPerspective implements IHopPerspective {
     CTabItem tabItem = (CTabItem) event.item;
     MetadataEditor<?> editor = (MetadataEditor<?>) tabItem.getData();
 
-    if (editor.isCloseable()) {
-      editors.remove(editor);
-      tabItem.dispose();
+    boolean isRemoved = remove(editor);
 
-      // Refresh tree to remove bold
-      //
-      this.refresh();
-
-      // If all editor are closed
-      //
-      if (tabFolder.getItemCount() == 0) {
-        HopGui.getInstance().handleFileCapabilities(new EmptyFileType(), false, false, false);
-      }
-    } else {
-      // Ignore event if canceled
+    if (!isRemoved) {
       event.doit = false;
+      return;
+    }
+
+    // If all editor are closed
+    //
+    if (tabFolder.getItemCount() == 0) {
+      HopGui.getInstance().handleFileCapabilities(new EmptyFileType(), false, false, false);
     }
   }
 
@@ -512,6 +507,8 @@ public class MetadataPerspective implements IHopPerspective {
                 HopGui.getInstance().getVariables(), metadataProvider, metadataClass);
 
         manager.newMetadataWithEditor();
+
+        hopGui.getEventsHandler().fire(HopGuiEvents.MetadataCreated.name());
       } catch (Exception e) {
         new ErrorDialog(
             getShell(),
@@ -540,6 +537,8 @@ public class MetadataPerspective implements IHopPerspective {
         try {
           MetadataManager<IHopMetadata> manager = getMetadataManager(objectKey);
           manager.editWithEditor(objectName);
+
+          hopGui.getEventsHandler().fire(HopGuiEvents.MetadataChanged.name());
         } catch (Exception e) {
           new ErrorDialog(getShell(), "Error", "Error editing metadata", e);
         }
@@ -603,6 +602,12 @@ public class MetadataPerspective implements IHopPerspective {
       text.selectAll();
       text.setFocus();
       treeEditor.setEditor(text, item);
+
+      try {
+        hopGui.getEventsHandler().fire(HopGuiEvents.MetadataChanged.name());
+      } catch (HopException e) {
+        throw new RuntimeException("Error fire metadata changed event", e);
+      }
     }
   }
 
@@ -628,6 +633,8 @@ public class MetadataPerspective implements IHopPerspective {
 
         refresh();
         updateSelection();
+
+        hopGui.getEventsHandler().fire(HopGuiEvents.MetadataDeleted.name());
       } catch (Exception e) {
         new ErrorDialog(getShell(), "Error", "Error delete metadata", e);
       }
@@ -666,6 +673,8 @@ public class MetadataPerspective implements IHopPerspective {
           }
         }
         refresh();
+
+        hopGui.getEventsHandler().fire(HopGuiEvents.MetadataCreated.name());
       } catch (Exception e) {
         new ErrorDialog(
             getShell(),
@@ -719,7 +728,7 @@ public class MetadataPerspective implements IHopPerspective {
       toolTip = "i18n::MetadataPerspective.ToolbarElement.Refresh.Tooltip",
       image = "ui/images/refresh.svg")
   @GuiKeyboardShortcut(key = SWT.F5)
-  @GuiOsxKeyboardShortcut(key = SWT.F5)  
+  @GuiOsxKeyboardShortcut(key = SWT.F5)
   public void refresh() {
     try {
       tree.setRedraw(false);
@@ -778,6 +787,8 @@ public class MetadataPerspective implements IHopPerspective {
       TreeMemory.setExpandedFromMemory(tree, METADATA_PERSPECTIVE_TREE);
 
       tree.setRedraw(true);
+
+      updateGui();
     } catch (Exception e) {
       new ErrorDialog(
           getShell(),
