@@ -230,6 +230,12 @@ public class BaseTransformDialog extends Dialog {
       addDeprecation();
     }
   }
+  
+  public void setActive() {
+    if (shell != null && !shell.isDisposed() ) {
+      shell.setActive();      
+    }
+  }
 
   private void addDeprecation() {
 
@@ -633,31 +639,8 @@ public class BaseTransformDialog extends Dialog {
     setSize(shell, -1, -1, true);
   }
 
-  public static void setSize(Shell shell, int prefWidth, int prefHeight) {
-    PropsUi props = PropsUi.getInstance();
-
-    WindowProperty winprop = props.getScreen(shell.getText());
-    if (winprop != null) {
-      winprop.setShell(shell, prefWidth, prefHeight);
-    } else {
-      shell.layout();
-
-      winprop = new WindowProperty(shell.getText(), false, 0, 0, prefWidth, prefHeight);
-      winprop.setShell(shell);
-
-      // Now, as this is the first time it gets opened, try to put it in the middle of the screen...
-      Rectangle shellBounds = shell.getBounds();
-      Monitor monitor = shell.getDisplay().getPrimaryMonitor();
-      if (shell.getParent() != null) {
-        monitor = shell.getParent().getMonitor();
-      }
-      Rectangle monitorClientArea = monitor.getClientArea();
-
-      int middleX = monitorClientArea.x + (monitorClientArea.width - shellBounds.width) / 2;
-      int middleY = monitorClientArea.y + (monitorClientArea.height - shellBounds.height) / 2;
-
-      shell.setLocation(middleX, middleY);
-    }
+  public static void setSize(Shell shell, int minWidth, int minHeight) {
+    setSize(shell, minWidth, minHeight, false);
   }
 
   /**
