@@ -21,7 +21,6 @@ import org.apache.hop.core.Const;
 import org.apache.hop.core.variables.IVariables;
 import org.apache.hop.i18n.BaseMessages;
 import org.apache.hop.ui.core.dialog.BaseDialog;
-import org.apache.hop.ui.core.gui.WindowProperty;
 import org.apache.hop.ui.pipeline.transform.BaseTransformDialog;
 import org.apache.hop.ui.workflow.action.ActionDialog;
 import org.apache.hop.ui.workflow.dialog.WorkflowDialog;
@@ -51,8 +50,6 @@ public class ActionStartDialog extends ActionDialog implements IActionDialog {
 
   private static final String MONTHLY = BaseMessages.getString(PKG, "ActionStart.Type.Monthly");
 
-  private Shell shell;
-
   private ActionStart action;
 
   private Text wName;
@@ -228,11 +225,6 @@ public class ActionStartDialog extends ActionDialog implements IActionDialog {
     return action;
   }
 
-  public void dispose() {
-    props.setScreen(new WindowProperty(shell));
-    shell.dispose();
-  }
-
   public void getData() {
     wName.setText(action.getName());
     wRepeat.setSelection(action.isRepeat());
