@@ -22,13 +22,18 @@ import org.apache.hop.core.exception.HopException;
 import org.apache.hop.core.gui.plugin.GuiPlugin;
 import org.apache.hop.core.plugins.IPlugin;
 import org.apache.hop.core.plugins.PluginRegistry;
+import org.apache.hop.execution.ExecutionInfoLocation;
 import org.apache.hop.i18n.BaseMessages;
+import org.apache.hop.metadata.api.IHopMetadataProvider;
+import org.apache.hop.metadata.api.IHopMetadataSerializer;
 import org.apache.hop.ui.core.PropsUi;
+import org.apache.hop.ui.core.dialog.ErrorDialog;
 import org.apache.hop.ui.core.gui.GuiCompositeWidgets;
 import org.apache.hop.ui.core.gui.GuiCompositeWidgetsAdapter;
 import org.apache.hop.ui.core.metadata.MetadataEditor;
 import org.apache.hop.ui.core.metadata.MetadataManager;
 import org.apache.hop.ui.core.widget.ComboVar;
+import org.apache.hop.ui.core.widget.MetaSelectionLine;
 import org.apache.hop.ui.hopgui.HopGui;
 import org.apache.hop.workflow.config.IWorkflowEngineRunConfiguration;
 import org.apache.hop.workflow.config.WorkflowRunConfiguration;
@@ -61,6 +66,7 @@ public class WorkflowRunConfigurationEditor extends MetadataEditor<WorkflowRunCo
 
   private Text wName;
   private Text wDescription;
+  private MetaSelectionLine<ExecutionInfoLocation> wExecutionInfoLocation;
   private ComboVar wPluginType;
 
   private Composite wPluginSpecificComp;
@@ -166,6 +172,27 @@ public class WorkflowRunConfigurationEditor extends MetadataEditor<WorkflowRunCo
     wDescription.setLayoutData(fdDescription);
     lastControl = wDescription;
 
+    // Which location should the execution information go to?
+    //
+    wExecutionInfoLocation =
+            new MetaSelectionLine<>(
+                    manager.getVariables(),
+                    manager.getMetadataProvider(),
+                    ExecutionInfoLocation.class,
+                    parent,
+                    SWT.SINGLE | SWT.LEFT,
+                    BaseMessages.getString(
+                            PKG, "WorkflowRunConfigurationDialog.label.ExecutionInfoLocation"),
+                    BaseMessages.getString(
+                            PKG, "WorkflowRunConfigurationDialog.toolTip.ExecutionInfoLocation"));
+    props.setLook(wExecutionInfoLocation);
+    FormData fdExecutionInfoLocation = new FormData();
+    fdExecutionInfoLocation.top = new FormAttachment(lastControl, margin);
+    fdExecutionInfoLocation.left = new FormAttachment(0, 0); // To the right of the label
+    fdExecutionInfoLocation.right = new FormAttachment(100, 0);
+    wExecutionInfoLocation.setLayoutData(fdExecutionInfoLocation);
+    lastControl = wExecutionInfoLocation;
+
     // What's the type of engine?
     //
     Label wlPluginType = new Label(parent, SWT.RIGHT);
@@ -290,6 +317,12 @@ public class WorkflowRunConfigurationEditor extends MetadataEditor<WorkflowRunCo
 
     wName.setText(Const.NVL(workingConfiguration.getName(), ""));
     wDescription.setText(Const.NVL(workingConfiguration.getDescription(), ""));
+    try {
+      wExecutionInfoLocation.fillItems();
+    } catch(Exception e) {
+      new ErrorDialog(getShell(), "Error", "Error getting the list of execution information locations", e);
+    }
+    wExecutionInfoLocation.setText(Const.NVL(workingConfiguration.getExecutionInfoLocationName(), ""));
     if (workingConfiguration.getEngineRunConfiguration() != null) {
       wPluginType.setText(
           Const.NVL(workingConfiguration.getEngineRunConfiguration().getEnginePluginName(), ""));
@@ -307,6 +340,7 @@ public class WorkflowRunConfigurationEditor extends MetadataEditor<WorkflowRunCo
 
     meta.setName(wName.getText());
     meta.setDescription(wDescription.getText());
+    meta.setExecutionInfoLocationName(wExecutionInfoLocation.getText());
 
     // Get the plugin specific information from the widgets on the screen
     //
